@@ -1,6 +1,23 @@
 /*
- * sarg - Squid user management log
- * Mar/98 - Pedro L Orso - orso@brturbo.com
+ * AUTHOR: Pedro Lineu Orso                             orso@brturbo.com
+ *                                                            1998, 2004
+ * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ * ---------------------------------------------------------------------
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
+ *
  */
 
 #include "include/conf.h"
@@ -10,43 +27,7 @@ extern numlist hours, weekdays;
 char wbuf[MAXLEN];
 char Msg[255];
 
-void getconf(debugm, ConfigFile, AccessLog, debug, BgColor, TxColor, TxBgColor, TiColor, LogoImage, LogoText, LogoTextColor, Width, Height, Title, BgImage, FontFace, HeaderColor, HeaderBgColor, FontSize, PasswdFile, TempDir, OutputDir, OutputEmail, Ip2Name, TopuserSortField, UserSortField, TopuserSortOrder, UserSortOrder, UserAgentLog, ExcludeHosts, DateFormat, ExcludeUsers, PerUserLimitFile, PerUserLimit, UserIp, MaxElapsed)
-   int debug;
-   int  debugm;
-   char *ConfigFile;
-   char *AccessLog;
-   char *BgColor;
-   char *TxColor;
-   char *TxBgColor;
-   char *TiColor;
-   char *LogoImage;
-   char *LogoText;
-   char *LogoTextColor;
-   char *Width;
-   char *Height;
-   char *Title;
-   char *BgImage;
-   char *FontFace;
-   char *HeaderColor;
-   char *HeaderBgColor;
-   char *FontSize;
-   char *PasswdFile;
-   char *TempDir;
-   char *OutputDir;
-   char *OutputEmail;
-   char *Ip2Name;
-   char *TopuserSortField;
-   char *UserSortField;
-   char *TopuserSortOrder;
-   char *UserSortOrder;
-   char *UserAgentLog;
-   char *ExcludeHosts;
-   char *ExcludeUsers;
-   char *DateFormat;
-   char *PerUserLimitFile;
-   char *PerUserLimit;
-   char *UserIp;
-   char *MaxElapsed;
+void getconf()
 {
 
    FILE *fp_in;
@@ -152,6 +133,13 @@ int parmtest(char *buf)
          return;
       }
 
+      if(strstr(buf,"show_sarg_logo") != 0) {
+         getword(wbuf,buf,' ');
+         strcpy(ShowSargLogo,buf);
+         fixnone(ShowSargLogo);
+         return;
+      }
+
       if(strstr(buf,"font_face") != 0) {
          getword(wbuf,buf,' ');
          strcpy(FontFace,buf);
@@ -174,9 +162,25 @@ int parmtest(char *buf)
       }
 
       if(strstr(buf,"font_size") != 0) {
+         if(strstr(buf,"header_font_size") == 0 && strstr(buf,"title_font_size") == 0) {
+            getword(wbuf,buf,' ');
+            strcpy(FontSize,buf);
+            fixnone(FontSize);
+            return;
+         }
+      }
+
+      if(strstr(buf,"header_font_size") != 0) {
          getword(wbuf,buf,' ');
-         strcpy(FontSize,buf);
-         fixnone(FontSize);
+         strcpy(HeaderFontSize,buf);
+         fixnone(HeaderFontSize);
+         return;
+      }
+
+      if(strstr(buf,"title_font_size") != 0) {
+         getword(wbuf,buf,' ');
+         strcpy(TitleFontSize,buf);
+         fixnone(TitleFontSize);
          return;
       }
 
@@ -445,10 +449,10 @@ int parmtest(char *buf)
          return;
       }
 
-      if(strstr(buf,"squidguard_log") != 0) {
+      if(strstr(buf,"squidguard_conf") != 0) {
          getword(wbuf,buf,' ');
-         strcpy(SquidGuardLogPath,buf);
-         fixnone(SquidGuardLogPath);
+         strcpy(SquidGuardConf,buf);
+         fixnone(SquidGuardConf);
          return;
       }
 
@@ -594,6 +598,121 @@ int parmtest(char *buf)
          fixnone(DisplayedValues);
          return;
       }
+
+      if(strstr(buf,"authfail_report_limit") != 0) {
+         getword(wbuf,buf,' ');
+         AuthfailReportLimit=atoi(buf);
+         return;
+      }
+
+      if(strstr(buf,"denied_report_limit") != 0) {
+         getword(wbuf,buf,' ');
+         DeniedReportLimit=atoi(buf);
+         return;
+      }
+
+      if(strstr(buf,"siteusers_report_limit") != 0) {
+         getword(wbuf,buf,' ');
+         SiteUsersReportLimit=atoi(buf);
+         return;
+      }
+
+      if(strstr(buf,"squidguard_report_limit") != 0) {
+         getword(wbuf,buf,' ');
+         SquidGuardReportLimit=atoi(buf);
+         return;
+      }
+
+      if(strstr(buf,"user_report_limit") != 0) {
+         getword(wbuf,buf,' ');
+         UserReportLimit=atoi(buf);
+         return;
+      }
+
+      if(strstr(buf,"www_document_root") != 0) {
+         getword(wbuf,buf,' ');
+         strcpy(wwwDocumentRoot,buf);
+         fixnone(wwwDocumentRoot);
+         return;
+      }
+
+      if(strstr(buf,"block_it") != 0) {
+         getword(wbuf,buf,' ');
+         strcpy(BlockIt,buf);
+         fixnone(BlockIt);
+         return;
+      }
+
+      if(strstr(buf,"external_css_file") != 0) {
+         getword(wbuf,buf,' ');
+         strcpy(ExternalCSSFile,buf);
+         fixnone(ExternalCSSFile);
+         return;
+      }
+
+      if(strstr(buf,"user_authentication") != 0) {
+         getword(wbuf,buf,' ');
+         strcpy(UserAuthentication,buf);
+         fixnone(UserAuthentication);
+         return;
+      }
+
+      if(strstr(buf,"AuthUserFile") != 0) {
+         getword(wbuf,buf,' ');
+         strcpy(AuthUserFile,buf);
+         fixnone(AuthUserFile);
+         return;
+      }
+
+      if(strstr(buf,"AuthName") != 0) {
+         getword(wbuf,buf,' ');
+         strcpy(AuthName,buf);
+         fixnone(AuthName);
+         return;
+      }
+
+      if(strstr(buf,"AuthType") != 0) {
+         getword(wbuf,buf,' ');
+         strcpy(AuthType,buf);
+         fixnone(AuthType);
+         return;
+      }
+
+      if(strstr(buf,"Require") != 0) {
+         getword(wbuf,buf,' ');
+         strcpy(Require,buf);
+         fixnone(Require);
+         return;
+      }
+
+      if(strstr(buf,"download_suffix") != 0) {
+         getword(wbuf,buf,'"');
+         getword(DownloadSuffix,buf,'"');
+         fixnone(DownloadSuffix);
+         return;
+      }
+
+      if(strstr(buf,"graphs") != 0) {
+         getword(wbuf,buf,' ');
+         strcpy(Graphs,buf);
+         fixnone(Graphs);
+         return;
+      }
+
+      if(strstr(buf,"graph_days_bytes_bar_color") != 0) {
+         getword(wbuf,buf,' ');
+         strcpy(GraphDaysBytesBarColor,buf);
+         fixnone(GraphDaysBytesBarColor);
+         return;
+      }
+
+      if(strstr(buf,"squidguard_log_format") != 0) {
+         getword(wbuf,buf,' ');
+         strcpy(SquidGuardLogFormat,buf);
+         fixnone(SquidGuardLogFormat);
+         return;
+      }
+
     
       return;
 }
