@@ -49,18 +49,52 @@
 #if HAVE_CTYPE_H
 #include <ctype.h>
 #endif
+#if HAVE_GD_H
+#include <gd.h>
+#define HAVE_GD
+gdImagePtr im;
+gdPoint points[4];
+#endif
+#if HAVE_GDFONTL_H
+#include <gdfontl.h>
+#endif
+#if HAVE_GDFONTT_H
+#include <gdfontt.h>
+#endif
+#if HAVE_GDFONTS_H
+#include <gdfonts.h>
+#endif
+#if HAVE_GDFONTMB_H
+#include <gdfontmb.h>
+#endif
+#if HAVE_GDFONTG_H
+#include <gdfontg.h>
+#endif
 
-#define MAXLEN 8192
+#if HAVE_FOPEN64
+#define _FILE_OFFSET_BITS 64
+#define MY_FOPEN fopen
+#else
+#define MY_FOPEN fopen
+#endif
+
+
+#define MAXLEN 20000
 long long int my_atoll (const char *nptr);
 
 FILE *fp_tt; 
 
-char buf[8192];
-char url[8192];
-char urly[8192];
+char outdir[MAXLEN];
+char dirname[MAXLEN];
+char buf[MAXLEN];
+char url[MAXLEN];
+char urly[MAXLEN];
 char user[MAXLEN];
+char periodo[MAXLEN];
 char msg[1024];
 char per_hour[128];
+char tmp[MAXLEN];
+char tmp2[MAXLEN];
 char tmp3[MAXLEN];
 char tmp4[MAXLEN];
 char tmp5[MAXLEN];
@@ -72,8 +106,12 @@ char datestimes[MAXLEN];
 char ConfigFile[MAXLEN];
 char href[MAXLEN];
 char href2[MAXLEN];
+char href3[MAXLEN];
 char df[20];
+char day[3], month[3], year[5];
 char ltext110[50];
+char cdfrom[30];
+char cduntil[30];
 char LastLog[5];
 char RemoveTempFiles[4];
 char ReplaceIndex[256];
@@ -119,6 +157,7 @@ char UserSortField[30];
 char TopuserSortOrder[10];
 char UserSortOrder[10];
 char UserAgentLog[255];
+char module[255];
 char ExcludeHosts[255];
 char ExcludeUsers[255];
 char DateFormat[2];
@@ -130,6 +169,8 @@ char datetimeby[10];
 char csort[255];
 char CharSet[255];
 char UserInvalidChar[255];
+char Graphs[5];
+char GraphDaysBytesBarColor[255];
 char Privacy[10];
 char PrivacyString[255];
 char PrivacyStringColor[30];
@@ -144,13 +185,22 @@ char DataFileFields[MAXLEN];
 char SiteUserTimeDateType[10];
 char ShowReadStatistics[5];
 char IndexSortOrder[5];
-char SquidGuardLogPath[MAXLEN];
+char SquidGuardConf[MAXLEN];
+char SquidGuarddbHome[255];
+char SquidGuardLogFormat[MAXLEN];
 char ShowSargInfo[5];
+char ShowSargLogo[5];
 char ParsedOutputLog[MAXLEN];
 char ParsedOutputLogCompress[255];
 char DisplayedValues[20];
+char HeaderFontSize[3];
+char TitleFontSize[3];
+char wwwDocumentRoot[MAXLEN];
+char ExternalCSSFile[MAXLEN];
+char BlockIt[255];
+char BlockImage[512];
 char hbc1[30];
-char hbc2[30];
+char hbc2[255];
 char hbc3[30];
 char hbc4[30];
 char hbc5[30];
@@ -159,42 +209,83 @@ char hbc7[30];
 char hbc8[30];
 char hbc9[30];
 char hbc10[30];
-
+char UserAuthentication[10];
+char AuthUserFile[255];
+char AuthName[512];
+char AuthType[255];
+char Require[512];
+char DownloadSuffix[MAXLEN];
 char *excludecode;
 char *userfile;
 char *str;
 char *str2;
 char text[200][255];
-char val1[255];
-char val2[255];
-char val3[255];
-char val4[255];
-char val5[255];
-char val6[255];
-char val7[255];
-char val8[255];
-char val9[255];
-char val10[255];
-char val11[255];
-char wwork1[255];
-char wwork2[255];
-char wwork3[255];
+char val1[MAXLEN];
+char val2[MAXLEN];
+char val3[MAXLEN];
+char val4[MAXLEN];
+char val5[MAXLEN];
+char val6[MAXLEN];
+char val7[MAXLEN];
+char val8[MAXLEN];
+char val9[MAXLEN];
+char val10[MAXLEN];
+char val11[MAXLEN];
+char wwork1[MAXLEN];
+char wwork2[MAXLEN];
+char wwork3[MAXLEN];
+char ftime[128];
 char mask[MAXLEN];
 char httplink[MAXLEN];
 char html_old[MAXLEN];
 char siteind[MAXLEN];
+char site[MAXLEN];
+char us[50];
+char email[MAXLEN];
 char test[1];
+char ouser2[255];
 char user2[MAXLEN];
+char wentp[512];
+char addr[MAXLEN];
+char suffix[10];
+char download_url[MAXLEN];
 int  excode;
+int  idate;
+int  smartfilter;
 int  denied_count;
+int  download_count;
 int  authfail_count;
 int  squidguard_count;
 int  limit_flag;
-int  z1, z2;
+int  color1;
+int  color2;
+int  color3;
+int  z1, z2, z3;
 int  ttopen;
 int  ind2;
+int  dfrom; 
+int  duntil;
 int  dataonly;
+int  indexonly;
+int  iprel;
+int  userip;
 int  langcode;
+int  debug;
+int  debugz;
+int  debugm;
+int  AuthfailReportLimit;
+int  DeniedReportLimit;
+int  SiteUsersReportLimit;
+int  SquidGuardReportLimit;
+int  UserReportLimit;
+int  download_flag;
+int  AuthfailReportLimit;
+int  DeniedReportLimit;
+int  SiteUsersReportLimit;
+int  SquidGuardReportLimit;
+int  UserReportLimit;
+int  download_flag;
+float perc;
 
 long long int twork;
 long long int twork2;
@@ -204,4 +295,7 @@ typedef struct
   int len;
 } numlist;
 
+DIR *dirp;
+struct dirent *direntp;
+
 int getnumlist( char *, numlist *, const int, const int );
