@@ -1,11 +1,28 @@
 /*
- * sarg - Squid user management log
- * Mar/98 - Pedro L Orso - orso@brturbo.com
+ * AUTHOR: Pedro Lineu Orso                             orso@brturbo.com
+ *                                                            1998, 2004
+ * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ * ---------------------------------------------------------------------
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
+ *
  */
 
 #include "include/conf.h"
 
-void geraindex(char *dirname, int debug, char *BgColor, char *TxColor, char *TxBgColor, char *TiColor, char *LogoImage, char *LogoText, char *LogoTextColor, char *Width, char *Height, char *Title, char *BgImage, char *FontFace, char *HeaderColor, char *HeaderBgColor, char *FontSize, char *TempDir, char *DateFormat, const char *periodo)
+void geraindex()
 {
 
    FILE *fp_ou, *fp_tmp, *tp_tmp2;
@@ -27,11 +44,12 @@ void geraindex(char *dirname, int debug, char *BgColor, char *TxColor, char *TxB
    char h[3], m[3], s[3];
 
    if(LastLog[0] != '\0')
-      mklastlog(dirname,debug);
+      mklastlog(outdir,debug);
 
-   sprintf(wdir,"%sindex.html",dirname);
-   sprintf(wdir_tmp,"%sindex.unsort",dirname);
-   sprintf(wdir_tmp2,"%sindex.sort",dirname);
+   sprintf(wdir,"%sindex.html",outdir);
+   sprintf(wdir_tmp,"%sindex.unsort",outdir);
+   sprintf(wdir_tmp2,"%sindex.sort",outdir);
+   strcpy(hbc1,"class=\"header\"");
 
    if(strcmp(Index,"no") == 0) {
       if(access(wdir, R_OK) == 0)
@@ -52,7 +70,7 @@ void geraindex(char *dirname, int debug, char *BgColor, char *TxColor, char *TxB
       exit(1);
    }
 
-   dirp = opendir(dirname);
+   dirp = opendir(outdir);
    while ( (direntp = readdir( dirp )) != NULL ){
       if(strstr(direntp->d_name,"-") == 0)
          continue;
@@ -64,9 +82,9 @@ void geraindex(char *dirname, int debug, char *BgColor, char *TxColor, char *TxB
       strcat(newname,month);
       strncat(newname,direntp->d_name+7,2);
 
-      obtdate(dirname,direntp->d_name,data);
-      obtuser(dirname,direntp->d_name,tuser);
-      obttotal(dirname,direntp->d_name,tbytes,tuser,media);
+      obtdate(outdir,direntp->d_name,data);
+      obtuser(outdir,direntp->d_name,tuser);
+      obttotal(outdir,direntp->d_name,tbytes,tuser,media);
      
       strcpy(html,data);
       getword(mon,html,' ');
@@ -87,8 +105,8 @@ void geraindex(char *dirname, int debug, char *BgColor, char *TxColor, char *TxB
    }
 
    fclose(fp_tmp);
-   (void)closedir( dirp );
    (void)rewinddir( dirp );
+   (void)closedir( dirp );
 
    if(strcmp(IndexSortOrder,"A") == 0)
       sprintf(html,"sort -t';' -k 7,7 %s -o %s", wdir_tmp, wdir_tmp2);
@@ -99,35 +117,37 @@ void geraindex(char *dirname, int debug, char *BgColor, char *TxColor, char *TxB
 
    unlink(wdir_tmp);
 
+   fputs("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\"",fp_ou);
+   fputs(" \"http://www.w3.org/TR/html4/loose.dtd\">\n",fp_ou);
    fputs("<html>\n",fp_ou);
    fputs("<head>\n",fp_ou);
    sprintf(html,"  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=%s\">\n",CharSet);
    fputs(html,fp_ou);
    fputs("</head>\n",fp_ou);
+   css(fp_ou);
 
-   if(strlen(FontFace) > 0) {
-      sprintf(html,"<font face=%s>\n",FontFace);
-      fputs(html,fp_ou);
-   }
-
-   sprintf(html,"<body bgcolor=%s text=%s background='%s'>\n",BgColor,TxColor,BgImage);
-   fputs(html,fp_ou);
-
-   fputs("<center><table cellpadding=0 cellspacing=0>\n",fp_ou);
+   sprintf(buf,"<body style=\"font-family:%s;font-size:%s;background-color:%s; \
+	background-image:url(%s)\">\n",FontFace,TitleFontSize,BgColor,BgImage);
+   fputs(buf,fp_ou);
 
+   sprintf(buf,"<center><table cellpadding=\"0\" cellspacing=\"0\">\n");
+   fputs(buf,fp_ou);
    if(strlen(LogoImage) > 0) {
-      sprintf(html,"<tr><th align=left><img src='%s' border=0 align=absmiddle width=%s height=%s><font color=%s>%s</font>\n",LogoImage,Width,Height,LogoTextColor,LogoText);
+      sprintf(html,"<tr><th align=\"center\"><img src=\"%s\" border=0 align=absmiddle width=%s height=%s> \
+	<font color=%s>%s</font></th></tr>\n",LogoImage,Width,Height,LogoTextColor,LogoText);
       fputs(html,fp_ou);
    }
-
-   sprintf(html,"<tr><th align=center><b><font color=%s size=+1>%s</font></b></th></tr>\n",TiColor,Title);
+   show_sarg(fp_ou, ".");
+   sprintf(html,"<tr><th class=\"title\">%s</th></tr>\n",Title);
    fputs(html,fp_ou);
-
    fputs("</table></center>\n",fp_ou);
-   fputs("<center><table cellpadding=1 cellspacing=1>\n",fp_ou);
-   fputs("<tr><td></td><td></td></tr>",fp_ou);
 
-   sprintf(html,"<tr><th bgcolor=%s><font size=%s color=%s>%s</font></th><th bgcolor=%s><font size=%s color=%s>%s</font></th><th bgcolor=%s><font size=%s color=%s>%s</font></th><th bgcolor=%s><font size=%s color=%s>%s</font></th><th bgcolor=%s><font size=%s color=%s>%s</font></th></tr>\n",HeaderBgColor,FontSize,HeaderColor,text[101],HeaderBgColor,FontSize,HeaderColor,text[102],HeaderBgColor,FontSize,HeaderColor,text[103],HeaderBgColor,FontSize,HeaderColor,text[93],HeaderBgColor,FontSize,HeaderColor,text[96]);
+   fputs("<center><table cellpadding=\"1\" cellspacing=\"2\">\n",fp_ou);
+   fputs("<tr><td></td><td></td></tr>\n",fp_ou);
+
+   sprintf(html,"<tr><th %s>%s</th><th %s>%s</th><th %s>%s \
+	</th><th %s>%s</th><th %s>%s</th></tr>\n", \
+	hbc1,text[101],hbc1,text[102],hbc1,text[103],hbc1,text[93],hbc1,text[96]);
    fputs(html,fp_ou);
 
    if((fp_tmp=fopen(wdir_tmp2,"r"))==NULL) {
@@ -143,7 +163,9 @@ void geraindex(char *dirname, int debug, char *BgColor, char *TxColor, char *TxB
       getword(tbytes,buf,';');
       getword(media,buf,';');
 
-      sprintf(html,"<tr><td bgcolor=%s><font size=%s><a href='%s/%s'>%s</font></a></td><td bgcolor=%s><font size=%s>%s</font></td><td align=right bgcolor=%s><font size=%s>%s</font></td><td align=right bgcolor=%s><font size=%s>%s</font></td><td align=right bgcolor=%s><font size=%s>%s</font></td></tr>\n",TxBgColor,FontSize,period,ReplaceIndex,period,TxBgColor,FontSize,data,TxBgColor,FontSize,tuser,TxBgColor,FontSize,tbytes,TxBgColor,FontSize,media);
+      sprintf(html,"<tr><td class=\"data\"><a href='%s/%s'>%s</a></td><td class=\"data\">%s</td> \
+	<td class=\"data\">%s</td><td class=\"data\">%s</td><td class=\"data\">%s</td></tr>\n", \
+	period,ReplaceIndex,period,data,tuser,tbytes,media);
       fputs(html,fp_ou);
    }
 
@@ -152,12 +174,9 @@ void geraindex(char *dirname, int debug, char *BgColor, char *TxColor, char *TxB
 
    zdate(ftime, DateFormat);
 
-   if(strcmp(ShowSargInfo,"yes") == 0) {
-      sprintf(html,"<br><br><center><font size=-2>%s <a href='%s'>%s-%s</a> %s %s</font></center>\n",text[108],URL,PGM,VERSION,text[109],ftime);
-      fputs(html,fp_ou);
-   }
+   show_info(fp_ou);
 
-   strcpy(html,"</html>\n");
+   strcpy(html,"</body>\n</html>\n");
    fputs(html,fp_ou);
 
    fclose(fp_ou);
