@@ -1,19 +1,38 @@
 /*
- * sarg - Squid user management log
- * Mar/98 - Pedro L Orso - orso@brturbo.com
+ * AUTHOR: Pedro Lineu Orso		                orso@brturbo.com
+ *                                                            1998, 2004
+ * SARG Squid Analysis Report Generator	           http://sarg-squid.org
+ * ---------------------------------------------------------------------
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
+ *
  */
 
 #include "include/conf.h"
 
+#define LEGACY_WRITE_USER
+#define LEGACY_WRITE_DOWNLOAD
+#define REPORT_EVERY_X_LINES 5000
+
+
 char *userfile;
 char *excludefile;
 char *excludeuser;
 
-//int m_wdays[ 7 ] = { 0, 1, 2, 3, 4, 5, 6 };
-//int mwd_limit = 7;
-//int m_hours[ 24 ] = { 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,
-//			13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23 };
-//int mh_limit = 24;
+char sz_Last_User[ MAXLEN ] = { 0 } ;
+int bool_ShowReadStatistics ;
 
 numlist weekdays = { { 0, 1, 2, 3, 4, 5, 6 }, 7 };
 numlist hours = { { 0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,
@@ -25,6 +44,8 @@ void getuexclude(char *uexfile, int debug);
 void ttx(char *user);
 int compar( const void *, const void * );
 
+#define _FILE_OFFSET_BITS 64
+
 int main(argc,argv)
    int argc;
    char *argv[];
@@ -32,6 +53,10 @@ int main(argc,argv)
 
    FILE *fp_in = NULL, *fp_ou = NULL, *fp_denied, *fp_usr, *fp_authfail, *fp_log;
 
+   char sz_Download_Unsort[ 20000 ] ;
+   FILE * fp_Download_Unsort = NULL ;
+   FILE * fp_Write_User = NULL ;
+
    extern int optind;
    extern int optopt;
    extern char *optarg;
@@ -47,58 +72,39 @@ int main(argc,argv)
    char wuser[MAXLEN]; 
    char code[MAXLEN];
    char code2[MAXLEN];
-   char periodo[MAXLEN];
+   char smartfilter[MAXLEN];
    char dia[128]; 
    char wdata[128];
    char mes[30];
    char ano[30];
    char hora[30];
-   char tmp[MAXLEN];
-   char tmp2[MAXLEN];
-   char tmp3[MAXLEN];
    char wtemp[MAXLEN];
    char wtemp2[255];
-   char us[50];
    char date[255];
    char arq[255];
    char arq_log[255];
    char warq[255][255];
-   char addr[MAXLEN];
    char hm[6];
-   char smartfilter[MAXLEN];
-   char site[MAXLEN];
    char uagent[MAXLEN];
    char hexclude[MAXLEN];
    char csort[MAXLEN]; 
    char tbuf[128];
    char tbuf2[128];
-   char email[MAXLEN];
    char zip[20];
    char *str;
-   char outdir[MAXLEN];
-   char cdfrom[30];
-   char cduntil[30];
-   char bufz[8192];
-   char bufy[8192];
+   char bufz[MAXLEN];
+   char bufy[MAXLEN];
    int  common; 
    int  common_log=0;
    int  squid_log=0;
-   int  userip=0;
-   int  indexonly=0;
    int  ch;
    int  d;
    int  x, l, i;
    int  errflg=0;
-   int  debug=0;
-   int  debugz=0;
-   int  debugm=0;
-   int  iprel=0;
    int  puser=0;
    int  fhost=0;
    int  dns=0;
    int  fuser=0;
-   int  dfrom=0; 
-   int  duntil=0;
    int  idata=0;
    int  narq=0;
    int  iarq=0;
@@ -115,10 +121,11 @@ int main(argc,argv)
    off_t recs1=0;
    unsigned long recs2=0;
 
+   int OutputNonZero = REPORT_EVERY_X_LINES ;
+
    BgImage[0]='\0';
    LogoImage[0]='\0';
    LogoText[0]='\0';
-   FontFace[0]='\0';
    PasswdFile[0]='\0';
    OutputEmail[0]='\0';
    Ip2Name[0]='\0';
@@ -132,19 +139,22 @@ int main(argc,argv)
    MaxElapsed[0]='\0';
    ReportType[0]='\0';
    UserTabFile[0]='\0';
+   BlockIt[0]='\0';
+   ExternalCSSFile[0]='\0';
 
    strcpy(AccessLog,"/usr/local/squid/var/logs/access.log");
    sprintf(ExcludeCodes,"%s/exclude_codes",SYSCONFDIR);
-   strcpy(BgColor,"white");
-   strcpy(TxColor,"black");
-   strcpy(TxBgColor,"beige");
-   strcpy(TiColor,"green");
+   strcpy(GraphDaysBytesBarColor,"orange");
+   strcpy(BgColor,"#FFFFFF");
+   strcpy(TxColor,"#000000");
+   strcpy(TxBgColor,"lavender");
+   strcpy(TiColor,"darkblue");
    strcpy(Width,"80");
    strcpy(Height,"45");
-   strcpy(LogoTextColor,"black");
+   strcpy(LogoTextColor,"#000000");
    strcpy(HeaderColor,"darkblue");
-   strcpy(HeaderBgColor,"blanchedalmond");
-   strcpy(FontSize,"-1");
+   strcpy(HeaderBgColor,"#DDDDDD");
+   strcpy(FontSize,"9px");
    strcpy(TempDir,"/tmp");
    strcpy(OutputDir,"/usr/local/etc/httpd/htdocs/squid-reports");
    strcpy(Ip2Name,"no");
@@ -166,6 +176,7 @@ int main(argc,argv)
    strcpy(TopsitesSortType,"D");
    strcpy(LongUrl,"no");
    strcpy(language,"English");
+   strcpy(FontFace,"Verdana,Tahoma,Arial");
    strcpy(datetimeby,"bytes");
    strcpy(CharSet,"ISO-8859-1");
    strcpy(Privacy,"no");
@@ -177,12 +188,21 @@ int main(argc,argv)
    strcpy(DataFileDelimiter,";");
    strcpy(DataFileFields,"user;date;time;url;connect;bytes;in_cache;out_cache;elapsed");
    strcpy(SiteUserTimeDateType,"table");
-   strcpy(ShowReadStatistics,"no");
+   strcpy(ShowReadStatistics,"yes");
    strcpy(IndexSortOrder,"D");
    strcpy(ShowSargInfo,"yes");
+   strcpy(ShowSargLogo,"yes");
    strcpy(ParsedOutputLog,"no");
    strcpy(ParsedOutputLogCompress,"/bin/gzip");
-   strcpy(DisplayedValues,"bytes");
+   strcpy(DisplayedValues,"abbreviation");
+   strcpy(HeaderFontSize,"9px");
+   strcpy(TitleFontSize,"11px");
+   strcpy(AuthUserFile,"/usr/local/sarg/passwd");
+   strcpy(AuthName,"SARG, Restricted Access");
+   strcpy(AuthType,"basic");
+   strcpy(Require,"require user admin %u");
+   strcpy(DownloadSuffix,"zip,arj,bzip,gz,ace,doc,iso,adt,bin,cab,dot,drv$,lha,lzh,mdb,mso,ppt,rtf,src,shs,sys,exe,dll,mp3,avi,mpg,mpeg");
+   strcpy(Graphs,"yes");
 
    dia[0]='\0';
    mes[0]='\0';
@@ -207,15 +227,28 @@ int main(argc,argv)
    zip[0]='\0';
    UserInvalidChar[0]='\0';
    DataFile[0]='\0';
+   SquidGuardConf[0]='\0';
 
    excode=0;
    denied_count=0;
+   download_count=0;
    authfail_count=0;
    squidguard_count=0;
+   DeniedReportLimit=10;
+   AuthfailReportLimit=10;
+   SquidGuardReportLimit=10;
+   UserReportLimit=0;
+   debug=0;
+   debugz=0;
+   debugm=0;
+   iprel=0;
+   userip=0;
+   color1=0;
+   color2=0;
+   color3=0;
 
    bzero(IncludeUsers, MAXLEN);
    bzero(ExcludeString, MAXLEN);
-   bzero(SquidGuardLogPath, MAXLEN);
 
    for(x=0; x<=254; x++) 
       warq[x][0]='\0';
@@ -367,7 +400,6 @@ int main(argc,argv)
       fprintf(stderr, "SARG:\n");
    }
 
-
    dataonly=0;
    if(DataFile[0] != '\0');
       dataonly++;
@@ -478,8 +510,8 @@ int main(argc,argv)
    strcpy(tmp6,tmp);
 
    if(strlen(email) > 0) {
-      sprintf(wtemp2,"mkdir -p %s/sarg_tmp",tmp2);
-      system(wtemp2);
+      sprintf(wtemp2,"%s/sarg_tmp",tmp2);
+      my_mkdir(wtemp2);
       strcat(tmp2,"/sarg_tmp");
       strcpy(outdir,tmp2);
       strcat(outdir,"/");
@@ -487,8 +519,14 @@ int main(argc,argv)
 
    strcat(tmp2,"/sarg.log");
 
-   sprintf(tmp3,"mkdir -p %s/sarg",tmp);
-   system(tmp3);
+   sprintf(warea,"%s/sarg",tmp);
+   if(access(warea, R_OK) == 0) {
+      sprintf(tmp3,"rm -rf %s",warea);
+      system(tmp3);
+   }
+   
+   sprintf(tmp3,"%s/sarg",tmp);
+   my_mkdir(tmp3);
    strcat(tmp4,"/denied.log.unsort");
    strcat(tmp5,"/denied.log");
    strcat(tmp6,"/authfail.log.unsort");
@@ -586,7 +624,7 @@ int main(argc,argv)
    }
 
    if(UserTabFile[0] != '\0') {
-      if(debug){
+      if(debug) {
          sprintf(msg,"%s: %s",text[86],UserTabFile);
          debuga(msg);
       }
@@ -623,6 +661,9 @@ int main(argc,argv)
       fclose(fp_usr);
    }
 
+   sprintf ( sz_Download_Unsort , "%s/sarg/download.unsort", tmp);
+   bool_ShowReadStatistics = ( strcmp(ShowReadStatistics,"yes") == 0 ) ;
+
    while(narq--) {
       strcpy(arq,warq[iarq]);
       iarq++;  
@@ -634,7 +675,11 @@ int main(argc,argv)
       debuga(msg);
    }
 
+#if defined(HAVE_FOPEN64)
+   if((fp_in=(long)fopen64(arq,"r"))==NULL) {
+#else
    if((fp_in=fopen(arq,"r"))==NULL) {
+#endif
      fprintf(stderr, "%s: (log) %s: %s\n",argv[0],text[8],arq);
      exit(1);
    }
@@ -650,8 +695,8 @@ int main(argc,argv)
 
    if(strcmp(ParsedOutputLog, "no") != 0 && !sarglog) {
       if(access(ParsedOutputLog,R_OK) != 0) {
-         sprintf(csort,"mkdir -p %s",ParsedOutputLog);
-         system(csort);
+         sprintf(csort,"%s",ParsedOutputLog);
+         my_mkdir(csort);
       }
       sprintf(arq_log,"%s/sarg_temp.log",ParsedOutputLog);
       if((fp_log=fopen(arq_log,"w"))==NULL) {
@@ -677,17 +722,30 @@ int main(argc,argv)
       }
    }
 
-   if(debug) {
+   // pre-Read the file only if I have to show stats
+   if(bool_ShowReadStatistics) {
+      rewind(fp_in);
       recs1=0;
-      while(fgets(bufz,sizeof(bufz),fp_in)!=NULL)
+      recs2=0;
+      while( fgets(bufz,sizeof(bufz),fp_in) != NULL )
          recs1++;
-      lseek(fileno(fp_in), 0, 0);
+      rewind(fp_in);
+
+      printf("SARG: Records in file: %d, reading: %3.2f%%\r",recs1,(float) 0);
+      fflush( stdout ) ;
    }
    
+    
    while(fgets(bufz,sizeof(bufz),fp_in)!=NULL) {
 	recs2++;
-	if(strcmp(ShowReadStatistics,"yes") == 0) 
-	   printf("SARG: Records in file=%d Reading=%d Rest=%d\r",recs1,recs2,recs1-recs2);
+	if( bool_ShowReadStatistics && ! --OutputNonZero ) {
+           perc = recs2 * 100 ;
+           perc = perc / recs1 ;
+	   printf("SARG: Records in file: %d, reading: %3.2f%%\r",recs1,perc);
+           fflush (stdout);
+           OutputNonZero = REPORT_EVERY_X_LINES ;
+        }
+        if(strlen(bufz) > MAXLEN-1) continue;
         if(!bufz[0]) continue;
         if(strstr(bufz,"HTTP/0.0") != 0) continue;
         if(strstr(bufz,"logfile turned over") != 0) continue;
@@ -799,7 +857,7 @@ int main(argc,argv)
         if(testvaliduserchar(user))
 	   continue;
 
-        if(strstr(user,"%5c") != 0) {
+        while(strstr(user,"%5c") != 0 || strstr(user,"%20") != 0) {
            getword(w,user,'%');
            strcpy(wuser,user+2);
            sprintf(user,"%s.%s",w,wuser);
@@ -816,6 +874,8 @@ int main(argc,argv)
 	         str[z1]='_';
 	      if(str[z1]==';')
 	         str[z1]='_';
+	      if(str[z1]=='\'')
+	         str[z1]='_';
 	      user[z2]=str[z1];
 	      z2++;
 	   }
@@ -826,6 +886,17 @@ int main(argc,argv)
         if(strstr(ReportType,"denied") != 0)
            strcpy(urly,url);
 
+        if(strlen(DownloadSuffix)) {
+           suffix[0]='\0';
+           download_flag=0;
+           strncpy(suffix,url+strlen(url)-3,3);
+           if(strstr(DownloadSuffix,suffix) != 0) {
+              strcpy(download_url,url);
+              download_flag=1;
+              download_count++;
+           }
+        }
+         
         if (strchr(url,'/')) {
            getword(w,url,'/');
            getword(w,url,'/');
@@ -965,18 +1036,96 @@ int main(argc,argv)
               } else sprintf(smartfilter,"\"\"");
 
               sprintf(bufz, "%s %s %s %s %s %s %s %s %s\n",dia,hora,user,ip,url,tam,code,elap,smartfilter);
+
+#ifdef LEGACY_WRITE_USER
               sprintf(tmp3,"%s/sarg/%s.unsort",tmp,user);
+#if defined(HAVE_FOPEN64)
+              if((fp_ou=fopen64(tmp3,"a"))==NULL) {
+#else
               if((fp_ou=fopen(tmp3,"a"))==NULL) {
+#endif
                 fprintf(stderr, "%s: (log) %s: %s\n",argv[0],text[9],tmp3);
                 exit(1);
               }
               fputs(bufz,fp_ou);
+
+#else
+// Check to see if user is the same of the previous line
+
+                  if ( strcmp ( user , sz_Last_User ) != 0 )
+                  {
+                        // NOT MATCHED - DIFFERENT USER
+                        // printf( "NOT MATCHED !!!!\n" ) ;
+                        // Close other file
+                        if ( fp_Write_User )
+                                fclose( fp_Write_User ) ;
+                        // Create new file name
+                        sprintf (tmp3, "%s/sarg/%s.unsort", tmp, user);
+
+                        // Open new file name
+#if defined(HAVE_FOPEN64)
+                        if ((fp_Write_User = fopen64 (tmp3, "a")) == NULL)
+                        {
+#else
+                        if ((fp_Write_User = fopen (tmp3, "a")) == NULL)
+                        {
+#endif
+                              fprintf (stderr, "%s: (log) %s: %s\n", argv[0], text[9], tmp3);
+                                exit (1);
+                        }
+//                        EachUserFopen++ ;
+
+                        // Store actual user for next iteration
+                        strcpy( sz_Last_User , user ) ;
+                  }
+
+                  // Store value
+                  fputs (bufz, fp_Write_User);
+
+#endif
+
               if(strcmp(ParsedOutputLog, "no") != 0 && !sarglog)
                  fputs(bufz,fp_log);
 
+#ifdef LEGACY_WRITE_USER
               fclose(fp_ou);
+#endif
 	      totregsg++;
 
+              if(download_flag) {
+                 sprintf(bufz, "%s %s %s %s %s\n",dia,hora,user,ip,download_url);
+
+#ifdef LEGACY_WRITE_DOWNLOAD
+                 sprintf(tmp3,"%s/sarg/download.unsort",tmp);
+#if defined(HAVE_FOPEN64)
+                 if((fp_ou=fopen64(tmp3,"a"))==NULL) {
+#else
+                 if((fp_ou=fopen(tmp3,"a"))==NULL) {
+#endif
+                    fprintf(stderr, "%s: (log) %s: %s\n",argv[0],text[9],tmp3);
+                    exit(1);
+                 }
+                 fputs(bufz,fp_ou);
+                 fclose(fp_ou);
+#else
+                 if ( ! fp_Download_Unsort )
+                 {
+#if defined(HAVE_FOPEN64)
+                      if ((fp_Download_Unsort = fopen64 ( sz_Download_Unsort, "a")) == NULL)
+                      {
+#else
+                      if ((fp_Download_Unsort = fopen (sz_Download_Unsort, "a")) == NULL)
+                      {
+#endif
+                          fprintf (stderr, "%s: (log) %s: %s\n", argv[0],
+                                   text[9], tmp3);
+                          exit (1);
+                        }
+                 }
+                 fputs (bufz, fp_Download_Unsort);
+#endif
+              }
+
               if(strstr(ReportType,"denied") != 0 || strstr(ReportType,"auth_failures") != 0) {
                  if(strstr(code,"DENIED/403") != 0) {
                     sprintf(bufz, "%s %s %s %s %s\n",dia,hora,user,ip,urly);
@@ -1017,11 +1166,17 @@ int main(argc,argv)
 	   }
         }
       }
+      if( bool_ShowReadStatistics )
+        printf("SARG: Records in file: %d, reading: %3.2f%%\n",recs1, (float) 100 );
    }
 
+   if ( fp_Download_Unsort ) 
+     fclose (fp_Download_Unsort);
+
+   if (fp_Write_User) 
+     fclose (fp_Write_User);
+
    if(debug) {
-      if(strcmp(ShowReadStatistics,"yes") == 0) 
-         printf("\n");
       sprintf(msg, "   %s: %ld, %s: %ld, %s: %ld",text[10],totregsl,text[11],totregsg,text[68],totregsx);
       debuga(msg);
   
@@ -1123,9 +1278,9 @@ int main(argc,argv)
 
    report_gen:
    if(strlen(DataFile) > 0)
-      data_file(tmp2,debug,periodo,debugz,iprel,outdir,addr,site,us,userip,email,wtemp2,BgColor,TxColor, TxBgColor,TiColor,LogoImage,LogoText,LogoTextColor,Width,Height,Title,BgImage,FontFace,HeaderColor,HeaderBgColor,FontSize,TempDir,Ip2Name,TopuserSortField,UserSortField,TopuserSortOrder,UserSortOrder,uagent,DateFormat,indexonly,PerUserLimitFile,PerUserLimit);
+      data_file(tmp);
    else
-      gerarel(tmp,debug,periodo,debugz,iprel,outdir,addr,site,us,userip,email,wtemp2,BgColor,TxColor, TxBgColor,TiColor,LogoImage,LogoText,LogoTextColor,Width,Height,Title,BgImage,FontFace,HeaderColor,HeaderBgColor,FontSize,TempDir,Ip2Name,TopuserSortField,UserSortField,TopuserSortOrder,UserSortOrder,uagent,DateFormat,indexonly,PerUserLimitFile,PerUserLimit);
+      gerarel();
 
    unlink(tmp2);
    if(strstr(ReportType,"denied") != 0)
