@@ -1,33 +1,42 @@
 /*
- * sarg - Squid user management log
- * Mar/98 - Pedro L Orso - orso@brturbo.com
+ * AUTHOR: Pedro Lineu Orso                             orso@brturbo.com
+ *                                                            1998, 2004
+ * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ * ---------------------------------------------------------------------
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
+ *
  */
 
 #include "include/conf.h"
+#include "include/defs.h"
 
-void criatmp(char *user, char *dirname, int debug, int indexonly);
-void criatmp_hora(char *user, char *dirname, int indexonly);
-void gravatmp(char *oldaccuser, char *dirname, char *oldurl, long long int nacc, long long int nbytes, char *oldmsg, long long int nelap, int indexonly, long long int incache, long long int oucache);
-void gravatmp_hora(char *dirname, char *user, char *data, char *hora, char *elap, char *accbytes, int indexonly);
-void gravatmpf(char *oldaccuser, char *dirname, char *oldurl, long long int nacc, long long int nbytes, char *oldmsg, long long int nelap, int indexonly, long long int incache, long long int oucache);
-void gravaporuser(char *user, char *dirname, char *url, char *ip, char *data, char *hora, char *tam, char *elap, int indexonly);
-void gravager(char *dirname, char *user, long long int nacc, char *url, long long int nbytes, char *ip, char *hora, char *dia, long long int nelap, long long int incache, long long int oucache);
-void grava_SmartFilter(char *dirname, char *user, char *ip, char *data, char *hora, char *url, char *smart);
-
-void gerarel(char *tmp, int debug, const char *periodo, int debugz, int iprel, char* outdir, char *addr, char *site, char *us, int userip, char *email, char *temp2, char *BgColor, char *TxColor, char *TxBgColor, char *TiColor, char *LogoImage, char *LogoText, char *LogoTextColor, char *Width, char *Height, char *Title, char *BgImage, char *FontFace, char *HeaderColor, char *HeaderBgColor, char *FontSize, char *TempDir, char *Ip2Name, char *TopuserSortField, char *UserSortField, char *TopuserSortOrder, char *UserSortOrder, char *UserAgentLog, char *DateFormat, int indexonly, char *PerUserLimitFile, char *PerUserLimit)
+void gerarel()
 {
 
    FILE *fp_in, *fp_ou;
 
    char accdia[11], acchora[9], accuser[MAXLEN], accip[MAXLEN], accurl[MAXLEN], accbytes[12], accelap[10];
    char oldaccdia[11], oldacchora[9], oldaccip[MAXLEN], wdir[MAXLEN], per1[MAXLEN];
-   char dirname[MAXLEN], wdirname[MAXLEN], oldurl[MAXLEN], oldaccuser[MAXLEN];
+   char wdirname[MAXLEN], oldurl[MAXLEN], oldaccuser[MAXLEN];
    char olduser[MAXLEN], oldmsg[50], acccode[50], oldaccelap[10], oldacccode[50], user[MAXLEN];
    char ipantes[MAXLEN], nameantes[MAXLEN], wdname[MAXLEN], wname2[MAXLEN]; 
    char accsmart[MAXLEN];
-   int  smartfilter=0;
    char wcrc[50];
    char crc2[50];
+   char u2[255];
    long long int nbytes=0; 
    long long int nelap=0; 
    long long int nacc=0;
@@ -40,11 +49,13 @@ void gerarel(char *tmp, int debug, const char *periodo, int debugz, int iprel, c
 
    ipantes[0]='\0';
    nameantes[0]='\0';
+   smartfilter=0;
 
    sprintf(dirname, "%s%s", outdir, periodo);
    sprintf(wdir, "%s%s", outdir, periodo);
    strcpy(per1,periodo);
-   vrfydir(wdir, dirname, per1, addr, site, us, debug, email);
+   strcpy(wdirname,dirname);
+   vrfydir(wdir, wdirname, per1, addr, site, us, email);
 
    if(debugz){
       debugaz("dirname",dirname);
@@ -52,22 +63,21 @@ void gerarel(char *tmp, int debug, const char *periodo, int debugz, int iprel, c
    }
  
    strcpy(wdirname,dirname);
-   gperiodo(wdirname, periodo, debug);
+   gperiodo(wdirname, periodo);
 
-   if(strlen(UserAgentLog) > 0 && email[0] == '\0') {
-      strcpy(wdirname,dirname);
-      useragent(wdirname,debug,outdir,TempDir,UserAgentLog,periodo,BgColor,TxColor,TxBgColor,TiColor,LogoImage,LogoText,LogoTextColor,Width,Height,Title,BgImage,FontFace,HeaderColor,HeaderBgColor,FontSize,Ip2Name, DateFormat);
-   }
+   if(strlen(UserAgentLog) > 0 && email[0] == '\0') 
+      useragent();
 
    olduser[0]='\0';
    strncat(tmp,"/sarg",5);
 
    dirp = opendir(tmp);
-   while ( (direntp = readdir( dirp )) != NULL ) {
+   while ((direntp = readdir( dirp )) != NULL ) {
       if(strstr(direntp->d_name,".log") == 0)
          continue;
+      if(strncmp(direntp->d_name,"download.log",12) == 0)
+         continue;
       sprintf(tmp3,"%s/%s",tmp,direntp->d_name);
-
       if((fp_in=fopen(tmp3,"r"))==NULL){
          fprintf(stderr, "SARG: (report) %s: %s\n",text[45],tmp);
          exit(1);
@@ -84,8 +94,8 @@ void gerarel(char *tmp, int debug, const char *periodo, int debugz, int iprel, c
       }
  
       strcpy(wdirname,dirname);
-      criatmp(user,tmp,debug,indexonly);
-      criatmp_hora(user,tmp,indexonly);
+      maketmp(user,tmp,debug,indexonly);
+      maketmp_hour(user,tmp,indexonly);
    
       ttopen=0;
       bzero(html_old, MAXLEN);
@@ -139,10 +149,8 @@ void gerarel(char *tmp, int debug, const char *periodo, int debugz, int iprel, c
             if(strcmp(oldaccuser,accuser) != 0){
                strcpy(oldmsg,"OK");
                if(strstr(oldacccode,"DENIED") != 0)
-               sprintf(oldmsg,"%s",text[46]);
-               strcpy(wdirname,dirname);
+                  sprintf(oldmsg,"%s",text[46]);
                gravatmp(oldaccuser,wdirname,oldurl,nacc,nbytes,oldmsg,nelap,indexonly,incache,oucache);
-               strcpy(wdirname,dirname);
                gravager(wdirname,oldaccuser,nacc,oldurl,nbytes,oldaccip,oldacchora,oldaccdia,nelap,
 				incache,oucache);
                nacc=0;
@@ -189,10 +197,15 @@ void gerarel(char *tmp, int debug, const char *periodo, int debugz, int iprel, c
                   str[z1]='_';
 	       if(str[z1]=='/')
                   str[z1]='_';
+	       if(str[z1]=='?')
+                  str[z1]='_';
                siteind[z2]=str[z1];
                z2++;
             }
-	    sprintf(arqtt,"%s/tt%s-%s.html",dirname,accuser,siteind);
+	    sprintf(arqtt,"%s/%s",dirname,accuser);
+	    if(access(arqtt, R_OK) != 0)
+               my_mkdir(arqtt);
+	    sprintf(arqtt,"%s/%s/tt%s-%s.html",dirname,accuser,accuser,siteind);
             if(strlen(arqtt) > 255) {
                strncpy(val7,arqtt,255);
                bzero(arqtt,MAXLEN);
@@ -216,17 +229,15 @@ void gerarel(char *tmp, int debug, const char *periodo, int debugz, int iprel, c
                   *s=tolower(*s);
             }
 
+            fputs("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\"",fp_tt);
+            fputs(" \"http://www.w3.org/TR/html4/loose.dtd\">\n",fp_tt);
             fputs("<html>\n",fp_tt);
             fputs("<head>\n",fp_tt);
             sprintf(html,"  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=%s\">\n",CharSet);
             fputs(html,fp_tt);
+            css(fp_tt);
             fputs("</head>\n",fp_tt);
 
-            if(strlen(FontFace) > 0) {
-               sprintf(html,"<font face=%s>\n",FontFace);
-               fputs(html,fp_tt);
-            }
-
             sprintf(html,"<body bgcolor=%s text=%s background='%s'>\n",BgColor,TxColor,BgImage);
             fputs(html,fp_tt);
 
@@ -237,33 +248,49 @@ void gerarel(char *tmp, int debug, const char *periodo, int debugz, int iprel, c
                fputs(html,fp_tt);
             }
 
-            sprintf(html,"<tr><th align=center colspan=2><b><font color=%s size=+1>%s</font></b></th></tr>\n",TiColor,Title);
-            fputs(html,fp_tt);
-            fputs("<tr><td></td></tr><tr><td></td></tr>",fp_tt);
-            fputs("</table></center>\n",fp_tt);
-            fputs("<center><table cellpadding=0 cellspacing=0>\n",fp_tt);
+	    show_sarg(fp_tt, "../..");
 
-            sprintf(html,"<tr><td align=right bgcolor=%s><font size=%s>%s:</font></td><td align=left bgcolor=%s><font size=%s>&nbsp;%s</font></td></td></tr>\n",HeaderBgColor,FontSize,text[89],TxBgColor,FontSize,periodo);
+            sprintf(html,"<tr><th class=\"title\" colspan=\"2\">%s</th></tr>\n",Title);
             fputs(html,fp_tt);
-            sprintf(html,"<tr><td align=right bgcolor=%s><font size=%s>%s:</font></td><td align=left bgcolor=%s><font size=%s>&nbsp;%s</font></td></td></tr>\n",HeaderBgColor,FontSize,text[90],TxBgColor,FontSize,name);
+
+            strcpy(u2,user);
+            if(strcmp(Ip2Name,"yes") == 0)
+               ip2name(u2);
+            if(UserTabFile[0] != '\0') {
+               sprintf(warea,":%s:",u2);
+               if((str=(char *) strstr(userfile,warea)) != (char *) NULL ) {
+                  z1=0;
+                  str2=(char *) strstr(str+1,":");
+                  str2++;
+                  bzero(name, MAXLEN);
+                  while(str2[z1] != ':') {
+                     name[z1]=str2[z1];
+                     z1++;
+                  }
+               } else strcpy(name,u2);
+            } else strcpy(name,u2);
+
+            sprintf(html,"<tr><td class=\"header\" colspan=\"2\">%s:&nbsp;%s</td></tr>\n",text[89],periodo);
             fputs(html,fp_tt);
-            sprintf(html,"<tr><td align=right bgcolor=%s><font size=%s>%s:</font></td><td align=left bgcolor=%s><font size=%s>&nbsp;%s, %s</font></td></td></tr>\n",HeaderBgColor,FontSize,text[104],TxBgColor,FontSize,UserSortField,UserSortOrder);
+            sprintf(html,"<tr><td class=\"header\" colspan=\"2\">%s:&nbsp;%s</td></tr>\n",text[90],name);
             fputs(html,fp_tt);
-            sprintf(html,"<tr><td align=center bgcolor=%s colspan=2><font size=%s>%s %s</font></td></tr>\n",HeaderBgColor,FontSize,text[32],text[55]);
+            sprintf(html,"<tr><td class=\"header\" colspan=\"2\">%s:&nbsp;%s, %s</td></tr>\n",text[104],UserSortField,UserSortOrder);
+            fputs(html,fp_tt);
+            sprintf(html,"<tr><td class=\"header3\" colspan=2>%s %s</td></tr>\n",text[32],text[55]);
             fputs(html,fp_tt);
 
             fputs("</table></center>\n",fp_tt);
-            fputs("<center><table cellpadding=1 cellspacing=1>\n",fp_tt);
+            fputs("<center><table cellpadding=\"0\" cellspacing=\"2\">\n",fp_tt);
             fputs("<tr><td></td><td></td></tr>",fp_tt);
             bzero(tmp4, MAXLEN);
             bzero(tmp5, MAXLEN);
             strncpy(tmp4,text[110],4);
             strncpy(tmp5,text[110]+5,4);
-            sprintf(html,"<tr><th align=left bgcolor=%s><font size=%s color=%s>%s</font></th><td></td><td></td><th bgcolor=%s><font size=%s color=%s>%s</font></th><td></td><td></td><th bgcolor=%s><font size=%s color=%s>%s</font></th></tr>\n",HeaderBgColor,FontSize,HeaderColor,text[91],HeaderBgColor,FontSize,HeaderColor,tmp4,HeaderBgColor,FontSize,HeaderColor,tmp5);
+            sprintf(html,"<tr><th class=\"data\">%s</th><th class=\"data\">%s</th><th class=\"data\">%s</th></tr>\n",text[91],tmp4,tmp5);
             fputs(html,fp_tt);
 	 }
 
-         sprintf(html,"<tr><td align=left bgcolor=%s><font size=%s>%s</font></td><td></td><td></td><td align=left bgcolor=%s><font size=%s>%s</font></td><td></td><td></td><td align=left bgcolor=%s><font size=%s>%s</font></td></tr>\n",TxBgColor,FontSize,accurl,TxBgColor,FontSize,accdia,TxBgColor,FontSize,acchora);
+         sprintf(html,"<tr><td class=\"data\">%s</td><td class=\"data\">%s</td><td class=\"data\">%s</td></tr>\n",accurl,accdia,acchora);
 
 	 if(strcmp(html,html_old) != 0)
             fputs(html,fp_tt);
@@ -283,7 +310,7 @@ void gerarel(char *tmp, int debug, const char *periodo, int debugz, int iprel, c
 
       if(strcmp(accuser,oldaccuser) != 0) {
          strcpy(wdirname,dirname);
-         totaliza_day(wdirname,oldaccuser,indexonly);
+         totaliza_day(tmp,oldaccuser,indexonly);
       }
 
       strcpy(oldaccuser,accuser);
@@ -294,7 +321,6 @@ void gerarel(char *tmp, int debug, const char *periodo, int debugz, int iprel, c
       strcpy(oldacchora,acchora);
 
    }
- 
    bzero(user,MAXLEN);
    fclose(fp_in);
    unlink(tmp3);
@@ -308,56 +334,44 @@ void gerarel(char *tmp, int debug, const char *periodo, int debugz, int iprel, c
    strcpy(wdirname,dirname);
    gravager(wdirname,oldaccuser,nacc,oldurl,nbytes,oldaccip,oldacchora,oldaccdia,nelap,incache,oucache);
    strcpy(wdirname,dirname);
-   totaliza_day(wdirname,oldaccuser,indexonly);
+   totaliza_day(tmp,oldaccuser,indexonly);
 
-   tmpsort(tmp, dirname, debug, TempDir, TopuserSortField, UserSortField, TopuserSortOrder, UserSortOrder, indexonly);
+   tmpsort();
 
    strcpy(wdirname,dirname);
    totalger(wdirname, debug, outdir);
 
    if(strlen(email) == 0) {
-      if(strlen(SquidGuardLogPath) > 0) {
-         strcpy(wdirname,dirname);
-         squidguard_log(wdirname, debug, outdir, userip, BgColor, TxColor, TxBgColor, TiColor, LogoImage, LogoText, LogoTextColor, Width, Height, Title, BgImage, FontFace, HeaderColor, HeaderBgColor, FontSize, TempDir, Ip2Name, TopuserSortField, TopuserSortOrder, UserAgentLog, DateFormat);
-      }
-      strcpy(wdirname,dirname);
-      topuser(wdirname, debug, outdir, userip, BgColor, TxColor, TxBgColor, TiColor, LogoImage, LogoText, LogoTextColor, Width, Height, Title, BgImage, FontFace, HeaderColor, HeaderBgColor, FontSize, TempDir, Ip2Name, TopuserSortField, TopuserSortOrder, UserAgentLog, DateFormat, smartfilter);
+      download_report();
 
-      if(strstr(ReportType,"topsites") != 0) {
+      if(strlen(SquidGuardConf) > 0) {
          strcpy(wdirname,dirname);
-         topsites(wdirname, debug, outdir, userip, BgColor, TxColor, TxBgColor, TiColor, LogoImage, LogoText, LogoTextColor, Width, Height, Title, BgImage, FontFace, HeaderColor, HeaderBgColor, FontSize, TempDir, Ip2Name, TopuserSortField, TopuserSortOrder, UserAgentLog, DateFormat);
-      }
-
-      if(strstr(ReportType,"sites_users") != 0) {
-         strcpy(wdirname,dirname);
-         siteuser(wdirname, debug, outdir, userip, BgColor, TxColor, TxBgColor, TiColor, LogoImage, LogoText, LogoTextColor, Width, Height, Title, BgImage, FontFace, HeaderColor, HeaderBgColor, FontSize, TempDir, Ip2Name, TopuserSortField, TopuserSortOrder, UserAgentLog, DateFormat);
+         squidguard_log();
       }
 
       strcpy(wdirname,dirname);
-      gen_denied_report(wdirname, debug, outdir, BgColor, TxColor, TxBgColor, TiColor, LogoImage, LogoText, LogoTextColor, Width, Height, Title, BgImage, FontFace, HeaderColor, HeaderBgColor, FontSize, TempDir, DateFormat);
+      topuser();
+
+      if(strstr(ReportType,"topsites") != 0)
+         topsites();
+
+      if(strstr(ReportType,"sites_users") != 0)
+         siteuser();
+      gen_denied_report();
 
       strcpy(wdirname,dirname);
-      authfail_report(wdirname, debug, outdir, BgColor, TxColor, TxBgColor, TiColor, LogoImage, LogoText, LogoTextColor, Width, Height, Title, BgImage, FontFace, HeaderColor, HeaderBgColor, FontSize, TempDir, DateFormat);
+      authfail_report();
 
-      if(smartfilter) {
-         strcpy(wdirname,dirname);
-         smartfilter_report(wdirname, debug, outdir, userip, BgColor, TxColor, TxBgColor, TiColor, LogoImage, LogoText, LogoTextColor, Width, Height, Title, BgImage, FontFace, HeaderColor, HeaderBgColor, FontSize, TempDir, Ip2Name, TopuserSortField, TopuserSortOrder, UserAgentLog, DateFormat);
-      }
+      if(smartfilter)
+         smartfilter_report();
 
-      if(strlen(SquidGuardLogPath) > 0) {
-//         strcpy(wdirname,dirname);
-//         squidguard_log(wdirname, debug, outdir, userip, BgColor, TxColor, TxBgColor, TiColor, LogoImage, LogoText, LogoTextColor, Width, Height, Title, BgImage, FontFace, HeaderColor, HeaderBgColor, FontSize, TempDir, Ip2Name, TopuserSortField, TopuserSortOrder, UserAgentLog, DateFormat);
-         strcpy(wdirname,dirname);
-         squidguard_report(wdirname, debug, outdir, userip, BgColor, TxColor, TxBgColor, TiColor, LogoImage, LogoText, LogoTextColor, Width, Height, Title, BgImage, FontFace, HeaderColor, HeaderBgColor, FontSize, TempDir, Ip2Name, TopuserSortField, TopuserSortOrder, UserAgentLog, DateFormat);
-      }
+      if(strlen(SquidGuardConf) > 0)
+         squidguard_report();
 
-      if(strstr(ReportType,"users_sites") != 0) {
-         strcpy(wdirname,dirname);
-         htmlrel(wdirname, debug, iprel, userip, BgColor, TxColor, TxBgColor, TiColor, LogoImage, LogoText, LogoTextColor, Width, Height, Title, BgImage, FontFace, HeaderColor, HeaderBgColor, FontSize, TempDir, UserSortField, UserSortOrder, DateFormat, indexonly, PerUserLimitFile, PerUserLimit, Ip2Name);
-      }
+      if(strstr(ReportType,"users_sites") != 0)
+         htmlrel();
 
-      strcpy(wdirname,outdir);
-      geraindex(wdirname, debug, BgColor, TxColor, TxBgColor, TiColor, LogoImage, LogoText, LogoTextColor, Width, Height, Title, BgImage, FontFace, HeaderColor, HeaderBgColor, FontSize, TempDir, DateFormat, periodo);
+      geraindex();
 
       if(strncmp(SuccessfulMsg,"yes",3) == 0)
          fprintf(stderr, "SARG: %s %s\n",text[47],dirname);
@@ -376,13 +390,13 @@ void gerarel(char *tmp, int debug, const char *periodo, int debugz, int iprel, c
       index_only(wdirname, debug);
    }
 
-   removetmp(dirname,debug);
+   removetmp(dirname);
 
    return;
 }
 
 
-void criatmp(char *user, char *dirname, int debug, int indexonly)
+void maketmp(char *user, char *dirname, int debug, int indexonly)
 {
 
    FILE *fp_ou;
@@ -392,7 +406,7 @@ void criatmp(char *user, char *dirname, int debug, int indexonly)
    if(indexonly) return;
    if(strstr(ReportType,"users_sites") == 0) return;
 
-   strcpy(wdirname,dirname);
+   strcpy(wdirname,tmp);
    strcat(wdirname,"/");
    strcat(wdirname,user);
 
@@ -401,7 +415,7 @@ void criatmp(char *user, char *dirname, int debug, int indexonly)
       debuga(msg);
    }
 
-   strcat(wdirname,".tmp");
+   strcat(wdirname,".utmp");
    if((fp_ou=fopen(wdirname,"w"))==NULL){
       fprintf(stderr, "SARG: (report) %s: %s\n",text[45],wdirname);
       exit(1);
@@ -412,7 +426,7 @@ void criatmp(char *user, char *dirname, int debug, int indexonly)
 }
 
 
-void criatmp_hora(char *user, char *dirname, int indexonly)
+void maketmp_hour(char *user, char *dirname, int indexonly)
 {
 
    FILE *fp_ou;
@@ -422,7 +436,7 @@ void criatmp_hora(char *user, char *dirname, int indexonly)
    if(indexonly) return;
    if(strstr(ReportType,"users_sites") == 0) return;
 
-   strcpy(wdirname,dirname);
+   strcpy(wdirname,tmp);
    strcat(wdirname,"/");
    strcat(wdirname,user);
 
@@ -448,10 +462,10 @@ void gravatmp(char *oldaccuser, char *dirname, char *oldurl, long long int nacc,
    if(indexonly) return;
    if(strstr(ReportType,"users_sites") == 0) return;
 
-   strcpy(wdirname,dirname);
+   strcpy(wdirname,tmp);
    strcat(wdirname,"/");
    strcat(wdirname,oldaccuser);
-   strcat(wdirname,".tmp");
+   strcat(wdirname,".utmp");
 
    if((fp_ou=fopen(wdirname,"a"))==NULL){
       fprintf(stderr, "SARG: (report) %s: %s\n",text[45],wdirname);
@@ -471,7 +485,7 @@ void gravatmp(char *oldaccuser, char *dirname, char *oldurl, long long int nacc,
 
    if(fp_tt) {
       fputs("</table>\n",fp_tt);
-      fputs("</html>\n",fp_tt);
+      fputs("</body>\n</html>\n",fp_tt);
       fclose(fp_tt);
    }
 
@@ -491,7 +505,7 @@ void gravatmp_hora(char *dirname, char *user, char *data, char *hora, char *elap
    if(indexonly) return;
    if(strstr(ReportType,"users_sites") == 0) return;
 
-   strcpy(wdirname,dirname);
+   strcpy(wdirname,tmp);
    strcat(wdirname,"/");
    strcat(wdirname,user);
    strcat(wdirname,".htmp");
@@ -523,7 +537,7 @@ void gravaporuser(char *user, char *dirname, char *url, char *ip, char *data, ch
    if(indexonly) return;
    if(strstr(ReportType,"users_sites") == 0) return;
 
-   strcpy(wdirname,dirname);
+   strcpy(wdirname,tmp);
    strcat(wdirname,"/");
    strcat(wdirname,user);
    strcat(wdirname,".ip");
@@ -554,10 +568,10 @@ void gravatmpf(char *oldaccuser, char *dirname, char *oldurl, long long int nacc
    if(indexonly) return;
    if(strstr(ReportType,"users_sites") == 0) return;
 
-   strcpy(wdirname,dirname);
+   strcpy(wdirname,tmp);
    strcat(wdirname,"/");
    strcat(wdirname,oldaccuser);
-   strcat(wdirname,".tmp");
+   strcat(wdirname,".utmp");
 
    if((fp_ou=fopen(wdirname,"a"))==NULL){
       fprintf(stderr, "SARG: (report) %s: %s\n",text[45],wdirname);
@@ -631,6 +645,7 @@ void grava_SmartFilter(char *dirname, char *user, char *ip, char *data, char *ho
 
    sprintf(reg,"%s %s %s %s %s %s\n",user,data,hora,ip,url,smart);
    fputs(reg,fp_ou);
+   fputs("</body>\n</html>\n",fp_tt);
 
    fclose(fp_ou);
 
