@@ -1,11 +1,29 @@
 /*
- * sarg - Squid user management log
- * Mar/98 - Pedro L Orso - orso@brturbo.com
+ * AUTHOR: Pedro Lineu Orso                             orso@brturbo.com
+ *                                                            1998, 2004
+ * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ * ---------------------------------------------------------------------
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
+ *
  */
 
+
 #include "include/conf.h"
 
-void siteuser(const char *dirname, int debug, const char *outdir, int userip, char *BgColor, char *TxColor, char *TxBgColor, char *TiColor, char *LogoImage, char *LogoText, char *LogoTextColor, char *Width, char *Height, char *Title, char *BgImage, char *FontFace, char *HeaderColor, char *HeaderBgColor, char *FontSize, char *TempDir, char *Ip2Name, char *TopuserSortField, char *TopuserSortOrder, char *UserAgentLog, char *DateFormat)
+void siteuser()
 {
 
    FILE *fp_in, *fp_ou;
@@ -29,7 +47,6 @@ void siteuser(const char *dirname, int debug, const char *outdir, int userip, ch
    int ucount=0;
    char *users;
 
-//   bzero(users, MAXLEN);
    sprintf(geral,"%s/geral",dirname);
    sprintf(sites,"%s/sites",dirname);
    sprintf(geral2,"%s/geral2",dirname);
@@ -57,10 +74,13 @@ void siteuser(const char *dirname, int debug, const char *outdir, int userip, ch
      exit(1);
    }
 
+   fputs("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\"",fp_ou);
+   fputs(" \"http://www.w3.org/TR/html4/loose.dtd\">\n",fp_ou);
    fputs("<html>\n",fp_ou);
    fputs("<head>\n",fp_ou);
    sprintf(html,"  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=%s\">\n",CharSet);
    fputs(html,fp_ou);
+   css(fp_ou);
    fputs("</head>\n",fp_ou);
 
    if(strlen(FontFace) > 0) {
@@ -71,27 +91,29 @@ void siteuser(const char *dirname, int debug, const char *outdir, int userip, ch
    sprintf(url,"<body bgcolor=%s text=%s background='%s'>\n",BgColor,TxColor,BgImage);
    fputs(url,fp_ou);
 
-   fputs("<center><table cellpadding=0 cellspacing=0>\n",fp_ou);
-
    if(strlen(LogoImage) > 0) {
-      sprintf(url,"<tr><th align=left><img src='%s' border=0 align=absmiddle width=%s height=%s><font color=%s>%s</font>\n",LogoImage,Width,Height,LogoTextColor,LogoText);
+      fputs("<center><table cellpadding=0 cellspacing=0>\n",fp_ou);
+      sprintf(url,"<tr><th align=\"center\"><img src='%s' border=0 align=absmiddle width=%s height=%s><font color=%s>%s</font>\n",LogoImage,Width,Height,LogoTextColor,LogoText);
       fputs(url,fp_ou);
+      fputs("</table>\n",fp_ou);
    }
 
-   sprintf(url,"<tr><th align=center><b><font color=%s size=+1>%s</font></b></th></tr>\n",TiColor,Title);
+   show_sarg(fp_ou, "..");
+   fputs("<center><table cellpadding=0 cellspacing=0>\n",fp_ou);
+   sprintf(url,"<tr><th class=\"title\">%s</th></tr>\n",Title);
    fputs(url,fp_ou);
 
-   sprintf(url,"<tr><td align=center bgcolor=%s><font size=%s>%s: %s</font></td></tr>\n",HeaderBgColor,FontSize,text[89],periodo);
+   sprintf(url,"<tr><td class=\"header3\">%s: %s</td></tr>\n",text[89],periodo);
    fputs(url,fp_ou);
-   sprintf(url,"<tr><td align=center bgcolor=%s><font size=%s>%s</font></td></tr>\n",HeaderBgColor,FontSize,text[85]);
+   sprintf(url,"<tr><td class=\"header3\">%s</td></tr>\n",text[85]);
    fputs(url,fp_ou);
    fputs("</table></center>\n",fp_ou);
 
-   fputs("<center><table cellpadding=0 cellspacing=1>\n",fp_ou);
+   fputs("<center><table cellpadding=0 cellspacing=2>\n",fp_ou);
    fputs("<tr><td></td></tr>\n",fp_ou);
    fputs("<tr><td></td></tr>\n",fp_ou);
    fputs("<tr><td></td></tr>\n",fp_ou);
-   sprintf(url,"<tr><th>&nbsp;</th><th>&nbsp;</th><th bgcolor=%s><font size=%s>%s</font></th><th>&nbsp;</th><th bgcolor=%s><font size=%s>%s</font></th></tr>\n",HeaderBgColor,FontSize,text[91],HeaderBgColor,FontSize,text[103]);
+   sprintf(url,"<tr><th class=\"header\">%s</th><th class=\"header\">%s</th><th class=\"header\">%s</th></tr>\n",text[100],text[91],text[103]);
    fputs(url,fp_ou);
   
    user[0]='\0';
@@ -132,8 +154,17 @@ void siteuser(const char *dirname, int debug, const char *outdir, int userip, ch
          }
       }
 
+      if(SiteUsersReportLimit) {
+         if(regs >= SiteUsersReportLimit)
+            continue;
+      }
+
+      if(strlen(BlockIt) > 0)
+         sprintf(BlockImage,"<a href=\"%s%s?url=%s\"><img src=\"../images/sarg-squidguard-block.png\" border=\"0\"></a>&nbsp;",wwwDocumentRoot,BlockIt,ourl);
+      else BlockImage[0]='\0';
+
       if(strcmp(url,ourl) != 0) {
-         sprintf(html,"<tr><td bgcolor=%s align=right><font size=%s>%d</font></td><td>&nbsp;</td><td align=left border=0 bgcolor=%s><font size=%s><a href=\"http://%s\">%s</font></td><td>&nbsp;</td><td bgcolor=%s align=left><font size=%s>%s</font></td></tr>\n",TxBgColor,FontSize,regs,TxBgColor,FontSize,ourl,ourl,TxBgColor,FontSize,users);
+         sprintf(html,"<tr><td class=\"data\">%d</td><td class=\"data2\">%s<a href=\"http://%s\">%s</td><td class=\"data2\">%s</td></tr>\n",regs,BlockImage,ourl,ourl,users);
          fputs(html,fp_ou);
          regs++;
          ucount=0;
@@ -143,20 +174,16 @@ void siteuser(const char *dirname, int debug, const char *outdir, int userip, ch
       }
    }
 
-   sprintf(html,"<tr><td bgcolor=%s align=right><font size=%s>%d</font></td><td>&nbsp;</td><td align=left border=0 bgcolor=%s><font size=%s><a href=\"http://%s\">%s</font></td><td>&nbsp;</td><td bgcolor=%s align=left><font size=%s>%s</font></td></tr>\n",TxBgColor,FontSize,regs,TxBgColor,FontSize,ourl,ourl,TxBgColor,FontSize,users);
+   sprintf(html,"<tr><td class=\"data\">%d</td><td class=\"data2\"><a href=\"http://%s\">%s</td><td class=\"data2\">%s</td></tr>\n",regs,ourl,ourl,users);
    fputs(html,fp_ou);
 
    unlink(geral2);
 
    fputs("</table></center>\n",fp_ou);
 
-   if(strcmp(ShowSargInfo,"yes") == 0) {
-      zdate(ftime, DateFormat);
-      sprintf(ourl,"<br><br><center><font size=-2>%s <a href='%s'>%s-%s</a> %s %s</font></center>\n",text[108],URL,PGM,VERSION,text[109],ftime);
-      fputs(ourl,fp_ou);
-   }
+   show_info(fp_ou);
 
-   fputs("</html>\n",fp_ou);
+   fputs("</body>\n</html>\n",fp_ou);
    
    fclose(fp_in);
    fclose(fp_ou);
