@@ -1,18 +1,34 @@
 /*
- * sarg - Squid user management log
- * Mar/98 - Pedro L Orso - orso@brturbo.com
+ * AUTHOR: Pedro Lineu Orso                             orso@brturbo.com
+ *                                                            1998, 2004
+ * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ * ---------------------------------------------------------------------
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
+ *
  */
 
 #include "include/conf.h"
 
-void tmpsort(char *tmp, const char *dirname, int debug, char *TempDir, char *TopuserSortField, char *UserSortField, char *TopuserSortOrder, char *UserSortOrder, int indexonly)
+void tmpsort()
 {
 
    DIR *dirp;
    struct dirent *direntp;
 
    char csort[MAXLEN];
-   char wentp[20];
    char arqou[MAXLEN], arqin[MAXLEN], wnome[MAXLEN], wnome2[MAXLEN];
    char field1[10]="2,2";
    char field2[10]="1,1";
@@ -26,8 +42,8 @@ void tmpsort(char *tmp, const char *dirname, int debug, char *TempDir, char *Top
    wnome2[0]='\0';
 
    dirp = opendir(tmp);
-   while ( (direntp = readdir( dirp )) != NULL ){
-      if(strstr(direntp->d_name,".tmp") == 0)
+   while ((direntp = readdir( dirp )) != NULL ){
+      if(strstr(direntp->d_name,".utmp") == 0)
          continue;
 
       strcpy(wentp,direntp->d_name);
@@ -37,12 +53,12 @@ void tmpsort(char *tmp, const char *dirname, int debug, char *TempDir, char *Top
       getword(wnome2,wentp,'.');
       strcat(wnome,wnome2);
 
-      if(strcmp(wentp,"tmp") !=0) {
+      if(strcmp(wentp,"utmp") !=0) {
          strcat(wnome,".");
          goto striptmp;
       }
 
-      strcpy(arqou,dirname);
+      strcpy(arqou,tmp);
       strcat(arqou,"/");
       strcpy(arqin,arqou);
       strcat(arqou,wnome);
@@ -84,8 +100,8 @@ void tmpsort(char *tmp, const char *dirname, int debug, char *TempDir, char *Top
 
    }
 
-   (void)closedir( dirp );
    (void)rewinddir( dirp );
+   (void)closedir( dirp );
    return;
 }
 
@@ -117,7 +133,11 @@ void sort_users_log(char *tmp, int debug)
          goto strip_unsort;
       }
 
-      sprintf(csort,"sort -T %s -k 5,5 -k 1,1 -k 2,2 -o %s/%s.log %s/%s.unsort", 
+      if(strcmp(direntp->d_name,"download.unsort") == 0)
+         sprintf(csort,"sort -T %s -k 3,3 -k 1,1 -k 2,2 -k 5,5 -o %s/%s.log %s/%s.unsort",
+					tmp, wtmp, user, wtmp, user);
+      else
+         sprintf(csort,"sort -T %s -k 5,5 -k 1,1 -k 2,2 -o %s/%s.log %s/%s.unsort", 
 					tmp, wtmp, user, wtmp, user);
       system(csort);
       sprintf(wdname,"%s/%s.unsort",wtmp,user);
@@ -125,8 +145,8 @@ void sort_users_log(char *tmp, int debug)
       bzero(user, MAXLEN);
 
    }
-   (void)closedir( dirp );
    (void)rewinddir( dirp );
+   (void)closedir( dirp );
 
    return;
 }
