@@ -1,11 +1,28 @@
 /*
- * sarg - Squid user management log
- * Mar/98 - Pedro L Orso - orso@brturbo.com
+ * AUTHOR: Pedro Lineu Orso                             orso@brturbo.com
+ *                                                            1998, 2004
+ * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ * ---------------------------------------------------------------------
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
+ *
  */
 
 #include "include/conf.h"
 
-void topsites(const char *dirname, int debug, const char *outdir, int userip, char *BgColor, char *TxColor, char *TxBgColor, char *TiColor, char *LogoImage, char *LogoText, char *LogoTextColor, char *Width, char *Height, char *Title, char *BgImage, char *FontFace, char *HeaderColor, char *HeaderBgColor, char *FontSize, char *TempDir, char *Ip2Name, char *TopuserSortField, char *TopuserSortOrder, char *UserAgentLog, char *DateFormat)
+void topsites()
 {
 
    FILE *fp_in, *fp_ou;
@@ -14,8 +31,11 @@ void topsites(const char *dirname, int debug, const char *outdir, int userip, ch
    char ourl[MAXLEN];
    char nacc[20];
    char nbytes[20];
+   char ntime[20];
+   char ntemp[20];
    char ttnacc[20];
    char ttnbytes[20];
+   char ttntime[20];
    char csort[255];
    char geral[MAXLEN];
    char geral2[MAXLEN];
@@ -29,9 +49,11 @@ void topsites(const char *dirname, int debug, const char *outdir, int userip, ch
    char sortt[10];
    long long int tnacc=0;
    long long int tnbytes=0;
-   long long int twork1=0, twork2=0;
+   long long int tntime=0;
+   long long int twork1=0, twork2=0, twork3=0;
    int regs=0;
 
+
    sprintf(geral,"%s/geral",dirname);
    sprintf(sites,"%s/sites",dirname);
    sprintf(geral2,"%s/geral2",dirname);
@@ -65,11 +87,16 @@ void topsites(const char *dirname, int debug, const char *outdir, int userip, ch
       if(strcmp(url,"TOTAL") == 0) {
          getword(ttnacc,buf,' ');
          getword(ttnbytes,buf,' ');
+         getword(ttntime,buf,' ');
          continue;
       }
       getword(nacc,buf,' ');
       getword(nbytes,buf,' ');
       getword(url,buf,' ');
+      getword(ntemp,buf,' ');
+      getword(ntemp,buf,' ');
+      getword(ntemp,buf,' ');
+      getword(ntime,buf,' ');
 
       if(!regs) {
          strcpy(ourl,url);
@@ -79,20 +106,24 @@ void topsites(const char *dirname, int debug, const char *outdir, int userip, ch
       if(strcmp(url,ourl) != 0) {
          my_lltoa(tnacc,val1,15);
          my_lltoa(tnbytes,val2,15);
-         sprintf(buf,"%s %s %s\n",val1,val2,ourl);
+         my_lltoa(tntime,val3,15);
+         sprintf(buf,"%s %s %s %s\n",val1,val2,val3,ourl);
          fputs(buf, fp_ou);
          strcpy(ourl,url);
          tnacc=0;
          tnbytes=0;
+         tntime=0;
       }
 
       tnacc+=my_atoll(nacc);
       tnbytes+=my_atoll(nbytes);
+      tntime+=my_atoll(ntime);
    }
 
    my_lltoa(tnacc,val1,15);
    my_lltoa(tnbytes,val2,15);
-   sprintf(buf,"%s %s %s\n",val1,val2,ourl);
+   my_lltoa(tntime,val3,15);
+   sprintf(buf,"%s %s %s %s\n",val1,val2,val3,ourl);
    fputs(buf, fp_ou);
 
    fclose(fp_in);
@@ -129,49 +160,42 @@ void topsites(const char *dirname, int debug, const char *outdir, int userip, ch
 
    regs=0;
 
+   fputs("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\"",fp_ou);
+   fputs(" \"http://www.w3.org/TR/html4/loose.dtd\">\n",fp_ou);
    fputs("<html>\n",fp_ou);
    fputs("<head>\n",fp_ou);
    sprintf(html,"  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=%s\">\n",CharSet);
    fputs(html,fp_ou);
+   css(fp_ou);
    fputs("</head>\n",fp_ou);
 
-   if(strlen(FontFace) > 0) {
-      sprintf(url,"<font face=%s>\n",FontFace);
-      fputs(url,fp_ou);
-   }
-
    sprintf(url,"<body bgcolor=%s text=%s background='%s'>\n",BgColor,TxColor,BgImage);
    fputs(url,fp_ou);
 
-   fputs("<center><table cellpadding=0 cellspacing=0>\n",fp_ou);
-
    if(strlen(LogoImage) > 0) {
-      sprintf(url,"<tr><th align=left><img src='%s' border=0 align=absmiddle width=%s height=%s><font color=%s>%s</font>\n",LogoImage,Width,Height,LogoTextColor,LogoText);
+      fputs("<center><table cellpadding=\"0\" cellspacing=\"0\">\n",fp_ou);
+      sprintf(url,"<tr><th align=\"center\"><img src='%s' border=0 align=absmiddle width=%s height=%s><font color=%s>%s</font>\n",LogoImage,Width,Height,LogoTextColor,LogoText);
       fputs(url,fp_ou);
+      fputs("</table>\n",fp_ou);
    }
 
-   sprintf(url,"<tr><th align=center><b><font color=%s size=+1>%s</font></b></th></tr>\n",TiColor,Title);
+   show_sarg(fp_ou,"..");
+   fputs("<center><table cellpadding=\"0\" cellspacing=\"0\">\n",fp_ou);
+   sprintf(url,"<tr><th class=\"title\">%s</th></tr>\n",Title);
    fputs(url,fp_ou);
 
-   sprintf(url,"<tr><td align=center bgcolor=%s><font size=%s>%s: %s</font></td></tr>\n",HeaderBgColor,FontSize,text[89],periodo);
+   sprintf(url,"<tr><td class=\"header3\">%s: %s</td></tr>\n",text[89],periodo);
    fputs(url,fp_ou);
-   sprintf(url,"<tr><td align=center bgcolor=%s><font size=%s>%s %s %s</font></td></tr>\n",HeaderBgColor,FontSize,text[83],TopSitesNum,text[84]);
+   sprintf(url,"<tr><td class=\"header3\">%s %s %s</td></tr>\n",text[83],TopSitesNum,text[84]);
    fputs(url,fp_ou);
    fputs("</table></center>\n",fp_ou);
 
-   fputs("<center><table cellpadding=0 cellspacing=1>\n",fp_ou);
+   fputs("<center><table cellpadding=\"1\" cellspacing=\"2\">\n",fp_ou);
    fputs("<tr><td></td></tr>\n",fp_ou);
-   fputs("<tr><td></td></tr>\n",fp_ou);
-   fputs("<tr><td></td></tr>\n",fp_ou);
-   sprintf(url,"<tr><th></th><td>&nbsp;</td>								\
-		<th bgcolor=%s><font size=%s color=%s>%s</font></th>					\
-		<td>&nbsp;</td>										\
-		<th bgcolor=%s><font size=%s color=%s>%s</font></th>					\
-		<td>&nbsp;</td>										\
-		<th bgcolor=%s><font size=%s color=%s>%s</font></th></tr>\n",				\
-		HeaderBgColor,FontSize,HeaderColor,text[91],						\
-		HeaderBgColor,FontSize,HeaderColor,text[92],						\
-		HeaderBgColor,FontSize,HeaderColor,text[93]);
+   sprintf(url,"<tr><td class=\"header\">%s</td><th class=\"header\">%s</th> \
+		<th class=\"header\">%s</th><th class=\"header\">%s</th> \
+		<th class=\"header\">%s</th></tr>\n", \
+		text[100],text[91],text[92],text[93],text[99]);
    fputs(url,fp_ou);
 
    regs=1;
@@ -181,28 +205,33 @@ void topsites(const char *dirname, int debug, const char *outdir, int userip, ch
          break;
       getword(nacc,buf,' ');
       getword(nbytes,buf,' ');
+      getword(ntime,buf,' ');
       getword(url,buf,' ');
 
       twork1=my_atoll(nacc);
       twork2=my_atoll(nbytes);
+      twork3=my_atoll(ntime);
 
       sprintf(wwork1,"%s",fixnum(twork1));
       sprintf(wwork2,"%s",fixnum(twork2));
+      sprintf(wwork3,"%s",fixnum(twork3));
 
-      sprintf(ourl,"<tr><td bgcolor=%s align=right><font size=%s>%d</font></td><td>&nbsp;</td><td align=right border=0 bgcolor=%s><font size=%s><a href=\"http://%s\">%s</font></td><td>&nbsp;</td><td bgcolor=%s align=right><font size=%s>%s</font></td><td>&nbsp;</td><td bgcolor=%s align=right><font size=%s>%s</font></td></tr>\n",TxBgColor,FontSize,regs,TxBgColor,FontSize,url,url,TxBgColor,FontSize,wwork1,TxBgColor,FontSize,wwork2);
+      if(strlen(BlockIt) > 0)
+         sprintf(BlockImage,"<a href=\"%s%s?url=%s\"><img src=\"../images/sarg-squidguard-block.png\" border=\"0\"></a>&nbsp;",wwwDocumentRoot,BlockIt,url);
+      else BlockImage[0]='\0';
+
+
+      sprintf(ourl,"<tr><td class=\"data\">%d</td><td class=\"data2\">%s<a href=\"http://%s\"><font class=\"link\">%s</font></td><td class=\"data\">%s</td><td class=\"data\">%s</td><td class=\"data\">%s</td></tr>\n",regs,BlockImage,url,url,wwork1,wwork2,wwork3);
       fputs(ourl,fp_ou);
       regs++;
    }
 
+
    fputs("</table></center>\n",fp_ou);
 
-   if(strcmp(ShowSargInfo,"yes") == 0) {
-      zdate(ftime, DateFormat);
-      sprintf(ourl,"<br><br><center><font size=-2>%s <a href='%s'>%s-%s</a> %s %s</font></center>\n",text[108],URL,PGM,VERSION,text[109],ftime);
-      fputs(ourl,fp_ou);
-   }
+   show_info(fp_ou);
 
-   fputs("</html>\n",fp_ou);
+   fputs("</body>\n</html>\n",fp_ou);
    
    fclose(fp_in);
    fclose(fp_ou);
