@@ -1,12 +1,28 @@
 /*
- * sarg - Squid user management log
- * Mar/98 - Pedro L Orso - orso@brturbo.com
+ * AUTHOR: Pedro Lineu Orso                             orso@brturbo.com
+ *                                                            1998, 2004
+ * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ * ---------------------------------------------------------------------
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
+ *
  */
 
 #include "include/conf.h"
 
-int topuser(const char *dirname, int debug, const char *outdir, int userip, char *BgColor, char *TxColor, char *TxBgColor, char *TiColor, char *LogoImage, char *LogoText, char *LogoTextColor, char *Width, char *Height, char *Title, char *BgImage, char *FontFace, char *HeaderColor, char *HeaderBgColor, char *FontSize, char *TempDir, char *Ip2Name, char *TopuserSortField, char *TopuserSortOrder, char *UserAgentLog, char *DateFormat, int smartfilter)
-
+int topuser()
 {
 
    FILE *fp_in, *fp_ou, *fp_top1, *fp_top2, *fp_top3;
@@ -29,7 +45,6 @@ int topuser(const char *dirname, int debug, const char *outdir, int userip, char
    int  totuser=0;
    int  topcount=0;
    char *s;
-   char mask2[255]="<th bgcolor=%s><font size=%s color=%s>%s</font></th>";
 
    ipantes[0]='\0';
    nameantes[0]='\0';
@@ -51,8 +66,8 @@ int topuser(const char *dirname, int debug, const char *outdir, int userip, char
    }
 
    if((fp_top1=fopen(top1,"w"))==NULL) {
-    fprintf(stderr, "SARG: (topuser) %s: %s\n",text[45],top1);
-    exit(1);
+      fprintf(stderr, "SARG: (topuser) %s: %s\n",text[45],top1);
+      exit(1);
    }
 
    if((fp_top2=fopen(top2,"w"))==NULL) {
@@ -159,6 +174,7 @@ int topuser(const char *dirname, int debug, const char *outdir, int userip, char
    if(strcmp(TopuserSortOrder,"normal") == 0)
       order[0]='\0';
 
+
    sprintf(csort,"sort -n -T %s %s -k %s -o %s %s", TempDir, order, sfield, top1, top2);
    system(csort);
 
@@ -182,7 +198,7 @@ int topuser(const char *dirname, int debug, const char *outdir, int userip, char
    }
 
  /*
- * Obtem o periodo
+ * get period
  */
 
    strcpy(arqper,dirname);
@@ -196,74 +212,80 @@ int topuser(const char *dirname, int debug, const char *outdir, int userip, char
    fgets(periodo,sizeof(periodo),fp_in);
    fclose(fp_in);
 
+   fputs("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\"",fp_top3);
+   fputs(" \"http://www.w3.org/TR/html4/loose.dtd\">\n",fp_top3);
    fputs("<html>\n",fp_top3);
    fputs("<head>\n",fp_top3);
    sprintf(html,"  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=%s\">\n",CharSet);
    fputs(html,fp_top3);
    fputs("</head>\n",fp_top3);
 
-   if(strlen(FontFace) > 0) {
-      sprintf(preg,"<font face=%s>\n",FontFace);
-      fputs(preg,fp_top3);
-   }
+   css(fp_top3);
 
-   sprintf(preg,"<body bgcolor=%s text=%s background='%s'>\n",BgColor,TxColor,BgImage);
+   sprintf(preg,"<body class=\"body\">");
    fputs(preg,fp_top3);
 
-   fputs("<center><table cellpadding=0 cellspacing=0>\n",fp_top3);
-
    if(strlen(LogoImage) > 0) {
-      sprintf(preg,"<tr><th align=left><img src='%s' border=0 align=absmiddle width=%s height=%s><font color=%s>%s</font>\n",LogoImage,Width,Height,LogoTextColor,LogoText);
+      fputs("<center><table cellpadding=\"0\" cellspacing=\"0\">\n",fp_top3);
+      sprintf(preg,"<tr><th align=\"center\"><img src='%s' border=0 align=absmiddle width=%s height=%s><font color=%s>%s</font></th></tr>\n",LogoImage,Width,Height,LogoTextColor,LogoText);
       fputs(preg,fp_top3);
+      fputs("</table>\n",fp_top3);
    }
 
-   sprintf(preg,"<tr><th align=center><b><font color=%s size=+1>%s</font></b></th></tr>\n",TiColor,Title);
+   show_sarg(fp_top3, "..");
+   fputs("<center><table cellpadding=\"0\" cellspacing=\"0\">\n",fp_top3);
+   sprintf(preg,"<tr><th align=\"center\" class=\"title\">%s</th></tr>\n",Title);
    fputs(preg,fp_top3);
 
-   sprintf(preg,"<tr><td align=center bgcolor=%s><font size=%s>%s: %s</font></td></tr>\n",HeaderBgColor,FontSize,text[89],periodo);
+   sprintf(preg,"<tr><td class=\"header3\">%s: %s</td></tr>\n",text[89],periodo);
    fputs(preg,fp_top3);
    strcat(wheader,(char *)text[104]);
    strcat(wheader,": ");
    strcat(wheader,TopuserSortField);
    strcat(wheader,", ");
    strcat(wheader,TopuserSortOrder);
-   sprintf(preg,"<tr><td align=center bgcolor=%s><font size=%s>%s</font></td></tr>\n",HeaderBgColor,FontSize,wheader);
+   sprintf(preg,"<tr><td class=\"header3\">%s</td></tr>\n",wheader);
    fputs(preg,fp_top3);
-   sprintf(preg,"<tr><td align=center bgcolor=%s><font size=%s>Topuser %s</font></td></tr>\n",HeaderBgColor,FontSize,text[55]);
+   sprintf(preg,"<tr><td class=\"header3\">Topuser %s</td></tr>\n",text[55]);
    fputs(preg,fp_top3);
 
    fputs("</table></center>\n",fp_top3);
-   fputs("<center><table cellpadding=0 cellspacing=1>\n",fp_top3);
-   fputs("<tr><td></td><td></td></tr>",fp_top3);
+   fputs("<center><table cellpadding=\"1\" cellspacing=\"2\">\n",fp_top3);
+   fputs("<tr><td><br></td><td></td></tr>\n",fp_top3);
 
    if(strstr(ReportType,"topsites") != 0) {
-      sprintf(preg,"<tr><td colspan=11><font size=-1><a href=\"topsites.html\">%s</a> %s</font></td></tr>\n",text[119],text[55]);
+      sprintf(preg,"<tr><td class=\"link\" colspan=11><a href=\"topsites.html\"><font class=\"link\">%s</font></a><font class=\"text\"> %s</font></td></tr>\n",text[119],text[55]);
       fputs(preg,fp_top3);
    }
 
    if(strstr(ReportType,"sites_users") != 0) {
-      sprintf(preg,"<tr><td colspan=11><font size=-1><a href=\"siteuser.html\">%s</a> %s</font></td></tr>\n",text[85],text[55]);
+      sprintf(preg,"<tr><td class=\"link\" colspan=11><a href=\"siteuser.html\"><font class=\"link\">%s</font></a><font class=\"text\"> %s</font></td></tr>\n",text[85],text[55]);
       fputs(preg,fp_top3);
    }
 
    if(squidguard_count) {
-     sprintf(preg,"<tr><td colspan=11><font size=-1><a href=\"squidguard.html\">%s</a> %s</font></td></tr>\n",text[122],text[55]);
+     sprintf(preg,"<tr><td class=\"link\" colspan=11><a href=\"squidguard.html\"><font class=\"link\">%s</font></a><font class=\"text\"> %s</font></td></tr>\n",text[122],text[55]);
      fputs(preg,fp_top3);
    }
 
+   if(download_count) {
+      sprintf(preg,"<tr><td class=\"link\" colspan=11><a href=\"download.html\"><font class=\"link\">%s</font></a><font class=\"text\"> %s</font></td></tr>\n",text[125],text[55]);
+      fputs(preg,fp_top3);
+   }
+
    if(denied_count) {
-      sprintf(preg,"<tr><td colspan=11><font size=-1><a href=\"denied.html\">%s</a> %s</font></td></tr>\n",text[118],text[55]);
+      sprintf(preg,"<tr><td class=\"link\" colspan=11><a href=\"denied.html\"><font class=\"link\">%s</font></a><font class=\"text\"> %s</font></td></tr>\n",text[118],text[55]);
       fputs(preg,fp_top3);
    }
 
    if(authfail_count) {
-      sprintf(preg,"<tr><td colspan=11><font size=-1><a href=\"authfail.html\">%s</a> %s</font></td></tr>\n",text[117],text[55]);
+      sprintf(preg,"<tr><td class=\"link\" colspan=11><a href=\"authfail.html\"><font class=\"link\">%s</font></a><font class=\"text\"> %s</font></td></tr>\n",text[117],text[55]);
       fputs(preg,fp_top3);
    }
 
    if(smartfilter) {
-     sprintf(preg,"<tr><td colspan=11><font size=-1><a href=\"smartfilter.html\">%s</a> %s</font></td></tr>\n",text[116],text[55]);
-     fputs(preg,fp_top3);
+      sprintf(preg,"<tr><td class=\"link\" colspan=11><a href=\"smartfilter.html\"><font class=\"link\">%s</font></a><font class=\"text\"> %s</font></td></tr>\n",text[116],text[55]);
+      fputs(preg,fp_top3);
    }
    strcpy(preg,"<tr><td></td></tr>\n");
    fputs(preg,fp_top3);
@@ -280,16 +302,16 @@ int topuser(const char *dirname, int debug, const char *outdir, int userip, char
    strcpy(val9,"colspan=2");
    bzero(val10, 255);
  
-   strcpy(hbc1,HeaderBgColor);
-   strcpy(hbc2,HeaderBgColor);
-   strcpy(hbc3,HeaderBgColor);
-   strcpy(hbc4,HeaderBgColor);
-   strcpy(hbc5,HeaderBgColor);
-   strcpy(hbc6,HeaderBgColor);
-   strcpy(hbc7,HeaderBgColor);
-   strcpy(hbc8,HeaderBgColor);
-   strcpy(hbc9,HeaderBgColor);
-   strcpy(hbc10,HeaderBgColor);
+   strcpy(hbc1,"class=\"header\"");
+   strcpy(hbc2,"class=\"header\"");
+   strcpy(hbc3,"class=\"header\"");
+   strcpy(hbc4,"class=\"header\"");
+   strcpy(hbc5,"class=\"header3\"");
+   strcpy(hbc6,"class=\"header\"");
+   strcpy(hbc7,"class=\"header\"");
+   strcpy(hbc8,"class=\"header\"");
+   strcpy(hbc9,"class=\"header\"");
+   strcpy(hbc10,"class=\"header\"");
 
    if(strstr(TopUserFields,"NUM") == 0) {
       bzero(val1, 255);
@@ -330,13 +352,10 @@ int topuser(const char *dirname, int debug, const char *outdir, int userip, char
       bzero(hbc8, 30);
    }
 
-   sprintf(preg,"<tr><th bgcolor=%s><font size=%s color=%s>%s</font></th><th bgcolor=%s><font size=%s color=%s></font></th><th align=left bgcolor=%s><font size=%s color=%s>%s</font></th><th bgcolor=%s><font size=%s color=%s>%s</font></th><th bgcolor=%s><font size=%s color=%s>%s</font></th><th bgcolor=%s><font size=%s color=%s>%s</font></th><th bgcolor=%s %s><font size=%s color=%s>%s</font>%s</th><th bgcolor=%s><font size=%s color=%s>%s</font></th><th bgcolor=%s><font size=%s color=%s>%s</font></th><th bgcolor=%s><font size=%s color=%s>%s</font></th></tr>\n",hbc1,FontSize,HeaderColor,val1,hbc1,FontSize,HeaderColor,hbc2,FontSize,HeaderColor,val2,hbc3,FontSize,HeaderColor,val3,hbc4,FontSize,HeaderColor,val4,hbc9,FontSize,HeaderColor,val11,hbc5,val9,FontSize,HeaderColor,val5,val10,hbc6,FontSize,HeaderColor,val6,hbc7,FontSize,HeaderColor,val7,hbc8,FontSize,HeaderColor,val8);
+     sprintf(preg,"<tr><th %s>%s</th><th %s></th><th %s>%s</th><th %s>%s</th><th %s>%s</th><th %s>%s</th><th %s %s>%s%s</th><th %s>%s</th><th %s>%s</th><th %s>%s</th></tr>\n",hbc1,val1,hbc1,hbc2,val2,hbc3,val3,hbc4,val4,hbc9,val11,hbc5,val9,val5,val10,hbc6,val6,hbc7,val7,hbc8,val8);
 
    fputs(preg,fp_top3);
 
-   strcpy(preg,"<tr><td></td></tr>\n");
-   fputs(preg,fp_top3);
-
    fscanf(fp_top1,"%s",user);
    fscanf(fp_top1,"%s",nbytes);
    fscanf(fp_top1,"%s",nacc);
@@ -371,16 +390,21 @@ int topuser(const char *dirname, int debug, const char *outdir, int userip, char
 
       strcpy(href," ");
       strcpy(href2," ");
+      strcpy(href3," ");
 
       if(strcmp(user,"TOTAL") != 0){
-         strcpy(href,"<a href='");
-         strcpy(href2,"<a href='d");
+         sprintf(href,"<a href='%s/",user);
+         sprintf(href2,"<a href='%s/d",user);
+         sprintf(href3,"<a href='%s/graph_day.png'>",user);
          strcat(href,user);
          strcat(href2,user);
          strcat(href,".html'>");
          strcat(href2,".html'>");
       }
 
+      if(strcmp(Graphs,"yes") != 0)
+         bzero(href3,MAXLEN);
+
       posicao++;
 
       tnelap=my_atoll(elap);
@@ -438,23 +462,28 @@ int topuser(const char *dirname, int debug, const char *outdir, int userip, char
       sprintf(wwork3,"%s",fixnum(tnelap));
 
       sprintf(val1,"%d",posicao);
-      sprintf(val2,"%s%s",href2,ltext110);
+#ifdef HAVE_GD
+      sprintf(val2,"%s<img src=\"../images/graph.png\" border=\"0\" title=\"%s %s\"></a>&nbsp;%s<img src=\"../images/datetime.png\" border=\"0\" title=\"%s %s\">\n",href3,text[126],text[55],href2,ltext110,text[55]);
+#else
+      sprintf(val2,"%s<img src=\"../images/datetime.png\" border=\"0\" title=\"%s %s\">\n",href2,ltext110,text[55]);
+#endif
+
       sprintf(val3,"%3.2f%%",perc);
       sprintf(val4,"%3.2f%%",inperc);
       sprintf(val5,"%3.2f%%",ouperc);
       sprintf(val6,"%s",buildtime(tnelap));
       sprintf(val7,"%3.2f%%",perc2);
 
-      strcpy(hbc1,TxBgColor);
-      strcpy(hbc2,TxBgColor);
-      strcpy(hbc3,TxBgColor);
-      strcpy(hbc4,TxBgColor);
-      strcpy(hbc5,TxBgColor);
-      strcpy(hbc6,TxBgColor);
-      strcpy(hbc7,TxBgColor);
-      strcpy(hbc8,TxBgColor);
-      strcpy(hbc9,TxBgColor);
-      strcpy(hbc10,TxBgColor);
+      strcpy(hbc1,"class=\"data\"");
+      strcpy(hbc2,"class=\"data2\"");
+      strcpy(hbc3,"class=\"data\"");
+      strcpy(hbc4,"class=\"data\"");
+      strcpy(hbc5,"class=\"data\"");
+      strcpy(hbc6,"class=\"data\"");
+      strcpy(hbc7,"class=\"data\"");
+      strcpy(hbc8,"class=\"data\"");
+      strcpy(hbc9,"class=\"data\"");
+      strcpy(hbc10,"class=\"data\"");
 
       if(strstr(TopUserFields,"NUM") == 0) {
          bzero(val1, 255);
@@ -500,11 +529,9 @@ int topuser(const char *dirname, int debug, const char *outdir, int userip, char
       if(strstr(ReportType,"users_sites") == 0)
          href[0]='\0';
 
-      sprintf(preg,"<tr><td align=right border=0 bgcolor=%s><font size=%s>%s</font></td><td bgcolor=%s><font size=%s>%s</font></td><td bgcolor=%s><font size=%s>%s%s</font></td><td align=right bgcolor=%s><font size=%s>%s</font></td><td align=right bgcolor=%s><font size=%s>%s</font></td><td align=right bgcolor=%s><font size=%s>%s</font></td><td align=right bgcolor=%s><font size=%s>%s</font></td><td align=right bgcolor=%s><font size=%s>%s</font></td><td align=center bgcolor=%s><font size=%s>%s</font></td><td align=right bgcolor=%s><font size=%s>%s</font><td align=right bgcolor=%s><font size=%s>%s</font></td></tr>\n",hbc1,FontSize,val1,hbc2,FontSize,val2,TxBgColor,FontSize,href,name,hbc3,FontSize,wwork1,hbc4,FontSize,wwork2,hbc5,FontSize,val3,hbc6,FontSize,val4,hbc7,FontSize,val5,hbc8,FontSize,val6,hbc9,FontSize,wwork3,hbc10,FontSize,val7);
+      sprintf(preg,"<tr><td %s>%s</td><td %s>%s</td><td %s>%s%s</td><td %s>%s</td><td %s>%s</td><td %s>%s</td><td %s>%s</td><td %s>%s</td><td %s>%s</td><td %s>%s<td %s>%s</td></tr>\n",hbc1,val1,hbc2,val2,hbc2,href,name,hbc3,wwork1,hbc4,wwork2,hbc5,val3,hbc6,val4,hbc7,val5,hbc8,val6,hbc9,wwork3,hbc10,val7);
 
       if(strstr(user,"TOTAL") != 0) {
-	 strcpy(preg,"<tr><td></td></tr><tr><td></td></tr>");
-         fputs(preg,fp_top3);
 
          if(atol(incac)) {
             inperc=ttnbytes / 100;
@@ -520,16 +547,16 @@ int topuser(const char *dirname, int debug, const char *outdir, int userip, char
 	 sprintf(wwork2,"%s",fixnum(ttnbytes));
 	 sprintf(wwork3,"%s",fixnum(ttnelap));
 
-         strcpy(hbc1,HeaderBgColor);
-         strcpy(hbc2,HeaderBgColor);
-         strcpy(hbc3,HeaderBgColor);
-         strcpy(hbc4,HeaderBgColor);
-         strcpy(hbc5,HeaderBgColor);
-         strcpy(hbc6,HeaderBgColor); 
-         strcpy(hbc7,HeaderBgColor);
-         strcpy(hbc8,HeaderBgColor);
-         strcpy(hbc9,HeaderBgColor);
-         strcpy(hbc10,HeaderBgColor);
+         strcpy(hbc1,"class=\"header2\"");
+         strcpy(hbc2,"class=\"header2\"");
+         strcpy(hbc3,"class=\"header2\"");
+         strcpy(hbc4,"class=\"header2\"");
+         strcpy(hbc5,"class=\"header2\"");
+         strcpy(hbc6,"class=\"header2\""); 
+         strcpy(hbc7,"class=\"header2\"");
+         strcpy(hbc8,"class=\"header2\"");
+         strcpy(hbc9,"class=\"header2\"");
+         strcpy(hbc10,"class=\"header\"");
 
          sprintf(val4,"%3.2f%%",inperc);
          sprintf(val5,"%3.2f%%",ouperc);
@@ -561,10 +588,9 @@ int topuser(const char *dirname, int debug, const char *outdir, int userip, char
 
          if(strstr(ReportType,"date_time") != 0) {
 	    if(strstr(TopUserFields,"TOTAL") != 0)
-               sprintf(preg,"<tr><td></td><th align=left bgcolor=%s><font size=%s color=%s>%s</th><td></td><th align=right bgcolor=%s><font size=%s color=%s>%s</th><th align=right bgcolor=%s><font size=%s color=%s>%15s</th><td></td><th align=right bgcolor=%s><font size=%s color=%s>%s</th><th align=left bgcolor=%s><font size=%s color=%s>%s</th><th align=center bgcolor=%s><font size=%s color=%s>%s</th><th align=right bgcolor=%s><font size=%s color=%s>%s</th></tr>\n",HeaderBgColor,FontSize,HeaderColor,text[107],hbc1,FontSize,HeaderColor,wwork1,hbc2,FontSize,HeaderColor,wwork2,hbc3,FontSize,HeaderColor,val4,hbc4,FontSize,HeaderColor,val5,hbc5,FontSize,HeaderColor,val6,hbc6,FontSize,HeaderColor,wwork3);
+               sprintf(preg,"<tr><td></td><td></td><th %s>%s</th><th %s>%s</th><th %s>%15s</th><td></td><th %s>%s</th><th %s>%s</th><th %s>%s</th><th %s>%s</th></tr>\n",hbc10,text[107],hbc1,wwork1,hbc2,wwork2,hbc3,val4,hbc4,val5,hbc5,val6,hbc6,wwork3);
 	 } else if(strstr(TopUserFields,"TOTAL") != 0)
-            sprintf(preg,"<tr><td></td><td></td><th align=left bgcolor=%s><font size=%s color=%s>%s</th><th align=right bgcolor=%s><font size=%s color=%s>%s</th><th align=right bgcolor=%s><font size=%s color=%s>%15s</th><td></td><th align=right bgcolor=%s><font size=%s color=%s>%s</th><th align=left bgcolor=%s><font size=%s color=%s>%s</th><th align=center bgcolor=%s><font size=%s color=%s>%s</th><th align=right bgcolor=%s><font size=%s color=%s>%s</th></tr>\n",HeaderBgColor,FontSize,HeaderColor,text[107],hbc1,FontSize,HeaderColor,wwork1,hbc2,FontSize,HeaderColor,wwork2,hbc3,FontSize,HeaderColor,val4,hbc4,FontSize,HeaderColor,val5,hbc5,FontSize,HeaderColor,val6,hbc6,FontSize,HeaderColor,wwork3);
-
+            sprintf(preg,"<tr><td></td><td></td><th %s>%s</th><th %s>%s</th><th %s>%15s</th><td></td><th %s>%s</th><th %s>%s</th><th %s>%s</th><th %s>%s</th></tr>\n",hbc10,text[107],hbc1,wwork1,hbc2,wwork2,hbc3,val4,hbc4,val5,hbc5,val6,hbc6,wwork3);
       }
 
       fputs(preg,fp_top3);
@@ -589,28 +615,47 @@ int topuser(const char *dirname, int debug, const char *outdir, int userip, char
    sprintf(wwork2,"%s",fixnum(tnbytes));
    sprintf(wwork3,"%s",fixnum(twork2));
 
+   if(strstr(TopUserFields,"CONNECT") == 0) {
+      bzero(wwork1, 255);
+      bzero(hbc1, 30);
+   }
+   if(strstr(TopUserFields,"BYTES") == 0) {
+      bzero(wwork2, 255);
+      bzero(hbc2, 30);
+   }
+   if(strstr(TopUserFields,"IN-CACHE-OUT") == 0) {
+      bzero(val4, 255);
+      bzero(val5, 255);
+      bzero(hbc3, 30);
+      bzero(hbc4, 30);
+   }
+   if(strstr(TopUserFields,"USED_TIME") == 0) {
+      bzero(val6, 255);
+      bzero(hbc5, 30);
+   }
+   if(strstr(TopUserFields,"MILISEC") == 0) {
+      bzero(wwork3, 255);
+      bzero(hbc6, 30);
+   }
+
    if((strstr(ReportType,"date_time") != 0 && strstr(TopUserFields,"AVERAGE") != 0)) {
-      sprintf(preg,"<tr><th></th><th align=left bgcolor=%s><font size=%s color=%s>%s</font></th><th></th><th align=right bgcolor=%s><font size=%s color=%s>%s</font></th><th align=right bgcolor=%s><font size=%s color=%s>%15s</font></th><td></td><td></td><td></td><th align=center bgcolor=%s><font size=%s color=%s>%s</font></th><th align=right bgcolor=%s><font size=%s color=%s>%s</font></th></tr>\n",HeaderBgColor,FontSize,HeaderColor,text[96],HeaderBgColor,FontSize,HeaderColor,wwork1,HeaderBgColor,FontSize,HeaderColor,wwork2,HeaderBgColor,FontSize,HeaderColor,buildtime(ttnelap/totuser),HeaderBgColor,FontSize,HeaderColor,wwork3);
+      sprintf(preg,"<tr><td></td><th></th><th %s>%s</th><th %s>%s</th><th %s>%15s</th><td></td><td></td><td></td><th %s>%s</th><th %s>%s</th></tr>\n",hbc10,text[96],hbc1,wwork1,hbc2,wwork2,hbc3,buildtime(ttnelap/totuser),hbc4,wwork3);
       fputs(preg,fp_top3);
     } else if(strstr(TopUserFields,"AVERAGE") != 0) {
-         sprintf(preg,"<tr><th></th><td></td><th align=left bgcolor=%s><font size=%s color=%s>%s</font></th><th align=right bgcolor=%s><font size=%s color=%s>%s</font></th><th align=right bgcolor=%s><font size=%s color=%s>%15s</font></th><td></td><td></td><td></td><th align=center bgcolor=%s><font size=%s color=%s>%s</font></th><th align=right bgcolor=%s><font size=%s color=%s>%s</font></th></tr>\n",HeaderBgColor,FontSize,HeaderColor,text[96],HeaderBgColor,FontSize,HeaderColor,wwork1,HeaderBgColor,FontSize,HeaderColor,wwork2,HeaderBgColor,FontSize,HeaderColor,buildtime(ttnelap/totuser),HeaderBgColor,FontSize,HeaderColor,wwork3);
+         sprintf(preg,"<tr><td></td><th></th><td></td><th %s>%s</th><th %s>%s</th><th %s>%15s</th><td></td><td></td><td></td><th %s>%s</th><th %s>%s</th></tr>\n",hbc10,text[96],hbc1,wwork1,hbc2,wwork2,hbc3,buildtime(ttnelap/totuser),hbc4,wwork3);
          fputs(preg,fp_top3);
    }
 
    if(strlen(UserAgentLog) > 0) {
       fputs("<tr><td></td></tr>\n",fp_top3);
       fputs("<tr><td></td></tr>\n",fp_top3);
-      fputs("<td align=left colspan=8><font size=-1><a href='useragent.html'>Useragent</a> Report</td>\n",fp_top3);
+      fputs("<td align=\"left\" colspan=8><font size=-1><a href='useragent.html'>Useragent</a> Report</td>\n",fp_top3);
    }
 
    strcpy(preg,"</table></center>");
    fputs(preg,fp_top3);
 
-   if(strcmp(ShowSargInfo,"yes") == 0) {
-     zdate(ftime, DateFormat);
-     sprintf(html,"<br><br><center><font size=-2>%s <a href='%s'>%s-%s</a> %s %s</font></center>\n",text[108],URL,PGM,VERSION,text[109],ftime);
-     fputs(html,fp_top3);
-   }
+   show_info(fp_top3);
 
 final:
    fclose(fp_top1);
@@ -626,7 +671,9 @@ final:
    sprintf(preg,"%d\n",totuser);
    fputs(preg,fp_ou);
 
+   fputs("</body>\n</html>\n",fp_top3);
+
    fclose(fp_ou);
 
-   return (0);
+   return;
 }
