@@ -1,11 +1,28 @@
 /*
- * sarg - Squid user management log
- * Mar/98 - Pedro L Orso - orso@brturbo.com
+ * AUTHOR: Pedro Lineu Orso                             orso@brturbo.com
+ *                                                            1998, 2004
+ * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ * ---------------------------------------------------------------------
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
+ *
  */
 
 #include "include/conf.h"
 
-void totaliza_day(const char *dirname, char *user, int indexonly)
+void totaliza_day(const char *tmp, char *user, int indexonly)
 {
 
    FILE *fp_in, *fp_ou;
@@ -30,9 +47,9 @@ void totaliza_day(const char *dirname, char *user, int indexonly)
    if(indexonly) return;
    if(strstr(ReportType,"users_sites") == 0) return;
 
-   sprintf(wdirname,"%s/%s.htmp",dirname,user);
-   sprintf(arqout,"%s/%s.day",dirname,user);
-   sprintf(sortout,"%s/%s.sort",dirname,user);
+   sprintf(wdirname,"%s/%s.htmp",tmp,user);
+   sprintf(arqout,"%s/%s.day",tmp,user);
+   sprintf(sortout,"%s/%s.sort",tmp,user);
 
    sprintf(csort,"sort -k 1,1 -k 2,2 -o %s %s",sortout,wdirname);
    system(csort);
@@ -69,8 +86,8 @@ void totaliza_day(const char *dirname, char *user, int indexonly)
       }
 
       if(strcmp(hora,ohora) != 0) {
-//         if(tused > telap)
-//            tused=telap;
+         if(tused > telap)
+            tused=telap;
 
          my_lltoa(telap,val1,15);
          sprintf(buf,"%s %s %s\n",odata,ohora,val1);
