@@ -1,12 +1,28 @@
 /*
- * sarg - Squid user management log
- * Mar/98 - Pedro L Orso - orso@brturbo.com
+ * AUTHOR: Pedro Lineu Orso                             orso@brturbo.com
+ *                                                            1998, 2004
+ * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ * ---------------------------------------------------------------------
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
+ *
  */
 
 #include "include/conf.h"
 
-void useragent(const char *dirname, int debug, const char *outdir, char *TempDir, char *UserAgentLog, const char *periodo, char *BgColor, char *TxColor, char *TxBgColor, char *TiColor, char *LogoImage, char *LogoText, char *LogoTextColor, char *Width, char *Height, char *Title, char *BgImage, char *FontFace, char *HeaderColor, char *HeaderBgColor, char *FontSize, char *Ip2Name, char *DateFormat)
-
+void useragent()
 {
 
    FILE *fp_in = NULL, *fp_ou = NULL, *fp_ht = NULL;
@@ -117,6 +133,8 @@ void useragent(const char *dirname, int debug, const char *outdir, char *TempDir
    if(debug)
       debuga(text[72]);
 
+   fputs("<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01 Transitional//EN\"",fp_ht);
+   fputs(" \"http://www.w3.org/TR/html4/loose.dtd\">\n",fp_ht);
    fputs("<html>\n",fp_ht);
    fputs("<head>\n",fp_ht);
    sprintf(html,"  <meta http-equiv=\"Content-Type\" content=\"text/html; charset=%s\">\n",CharSet);
@@ -131,13 +149,16 @@ void useragent(const char *dirname, int debug, const char *outdir, char *TempDir
    sprintf(html,"<body bgcolor=%s text=%s background='%s'>\n",BgColor,TxColor,BgImage);
    fputs(html,fp_ht);
 
-   fputs("<center><table cellpadding=0 cellspacing=0>\n",fp_ht);
 
    if(strlen(LogoImage) > 0) {
+      fputs("<center><table cellpadding=0 cellspacing=0>\n",fp_ht);
       sprintf(html,"<tr><th align=left><img src='%s' border=0 align=absmiddle width=%s height=%s><font color=%s>%s</font>\n",LogoImage,Width,Height,LogoTextColor,LogoText);
       fputs(html,fp_ht);
-      }
+      fputs("</table>\n",fp_ht);
+   }
 
+   show_sarg(fp_ht,"..");
+   fputs("<center><table cellpadding=0 cellspacing=0>\n",fp_ht);
    sprintf(html,"<tr><th align=center colspan=2><b><font color=%s size=+1>%s</font></b></th></tr>\n",TiColor,text[105]);
    fputs(html,fp_ht);
 
@@ -275,6 +296,7 @@ void useragent(const char *dirname, int debug, const char *outdir, char *TempDir
       fputs(html,fp_ht);
    }
 
+   fputs("</table>\n</body>\n</html>\n",fp_ht);
    fclose(fp_in);
    fclose(fp_ht);
 
