@@ -1,3 +1,28 @@
+/*
+ * AUTHOR: Pedro Lineu Orso                             orso@brturbo.com
+ *                                                            1998, 2004
+ * SARG Squid Analysis Report Generator            http://sarg-squid.org
+ * ---------------------------------------------------------------------
+ *
+ *  This program is free software; you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation; either version 2 of the License, or
+ *  (at your option) any later version.
+ *
+ *  This program is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with this program; if not, write to the Free Software
+ *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
+ *
+ */
+
+// #define LEGACY_MY_ATOLL
+// #define LEGACY_TESTVALIDUSERCHAR
+
 #include "include/conf.h"
 
 static char mtab1[12][4]={"Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"};
@@ -37,6 +62,36 @@ void getword(char *word, char *line, int stop)
   while((line[y++] = line[x++]));
 }
 
+char *  getword2(char *word, char *line, int stop)
+{
+  int x = 0 , y;
+  int limit=MAXLEN;
+
+  if(strlen(line) < 3) {
+     word[0]='\0';
+     return( line ) ;
+  }
+
+  // printf( "IN Buffer <%s>\n" , line ) ;
+  for(x=0;((line[x]) && (line[x] != stop && limit ));x++ , limit-- ) {
+     word[x] = line[x];
+  }
+  if(  ! limit) {
+        printf("SARG: getword2 loop detected.\n");
+        printf("SARG: Buffer=\"%s\"\n",line);
+        printf("SARG: searching for \'x%x\'\n",stop);
+        printf("SARG: Maybe you have a broken record or garbage in your access.log file.\n");
+        exit(1);
+  }
+
+  word[x] = '\0';
+  // printf( "Value <%s>\n" , word ) ;
+  // printf( "OUT Buffer <%s>\n" , line+x+1 ) ;
+  return( line + x +1) ;
+}
+
+#ifdef LEGACY_MY_ATOLL
+
 // BMG (bguillory@email.com)
 // 3 August 1999
 long long int my_atoll (const char *nptr)
@@ -65,6 +120,55 @@ long long int my_atoll (const char *nptr)
 
 } //my_atoll
 
+#else
+
+#define MAXLLL 30 //maximum number of digits in long long (a guess)
+long long int my_atoll (const char *nptr)
+{
+  long long int returnval=0;
+  char * t = nptr ;
+  int max_digits = MAXLLL ;
+
+  // Soak up all the white space
+  while (isspace( *t )) {
+    t++;
+  } //while
+
+  //For each character left to right
+  //change the character to a single digit
+  //multiply what we had before by 10 and add the new digit
+
+  for( ; --max_digits && isdigit( *t ) ; t++ )
+  {
+     returnval = ( returnval * 10 ) + ( *t - '0' ) ;
+  }
+
+  return returnval;
+
+} //my_atoll
+
+#endif
+
+
+void my_mkdir(char *name)
+{
+   char w0[255];
+   char w1[255];
+   char w2[255];
+
+   strcpy(w0,name);
+   strcpy(w2,"/");
+   getword(w1,w0,'/');
+   while(strstr(w0,"/") != 0) {
+      getword(w1,w0,'/');
+      strcat(w2,w1);
+      mkdir(w2,0755);
+      strcat(w2,"/");
+   }
+   strcat(w2,w0);
+   mkdir(w2,0755);
+}
+
 
 void my_lltoa(unsigned long long int n, char s[], int len)
 {
@@ -162,9 +266,7 @@ void fixper(char *tbuf, char *periodo, char *duntil)
 {
 
    char warea[50];
-   char dia[3];
-   char mes[3];
-   char ano[5];
+   char dia[5], mes[5], ano[5];
    int  x;
 
    warea[0]='\0';
@@ -259,22 +361,22 @@ char *fixnum(long long int inteiro)
       if(inteiro > 999 && inteiro <= 999999) {
          perc=inteiro / 1000;
          if((inteiro % 1000) >= 500) perc++;
-         sprintf(abbrev,"%3.0f K",perc);
+         sprintf(abbrev,"%3.0fK",perc);
       }
       if(inteiro >999999 && inteiro <= 999999999) {
          perc=inteiro / 1000000;
          if((inteiro % 1000000) >= 500) perc++;
-         sprintf(abbrev,"%3.0f M",perc);
+         sprintf(abbrev,"%3.0fM",perc);
       }
       if(inteiro > 999999999 && inteiro <= 999999999999) {
          perc=inteiro / 1000000000;
          if((inteiro % 1000000000) >= 500) perc++;
-         sprintf(abbrev,"%3.0f G",perc);
+         sprintf(abbrev,"%3.0fG",perc);
       }
       if(inteiro > 999999999999) {
          perc=inteiro / 1000000000000;
          if((inteiro % 1000000000000) >= 500) perc++;
-         sprintf(abbrev,"%3.0f T",perc);
+         sprintf(abbrev,"%3.0fT",perc);
       }
 
       return(abbrev);
@@ -437,7 +539,7 @@ void obttotal(char *dirname, char *name, char *tbytes, char *tuser, char *media)
 }
 
 
-void gperiodo(char *dirname, const char *periodo, int debug)
+void gperiodo(char *dirname, const char *periodo)
 {
  
    FILE *fp_ou;
@@ -463,12 +565,20 @@ void gperiodo(char *dirname, const char *periodo, int debug)
  
 }
 
-void vrfydir(char *dir, char *dirname, char *per1, char *addr, char *site, char *us, int debug, char *form)
+void vrfydir(char *dir, char *dirname, char *per1, char *addr, char *site, char *us, char *form)
 {
+   FILE *img_in, *img_ou;
    int  num=1, count=0;
+   int  c;
    char wdir[MAXLEN];
    char per2[MAXLEN];
+   char dirname2[MAXLEN];
+   char buffer[1024];
+   char images[512];
+   DIR *dirp;
+   struct dirent *direntp;
 
+   strcpy(dirname2,dirname);
    if(strcmp(OverwriteReport,"no") == 0) {
       while(num) {
          if(access(dirname,R_OK) == 0) {
@@ -492,7 +602,8 @@ void vrfydir(char *dir, char *dirname, char *per1, char *addr, char *site, char
       }
    }
 
-   sprintf(wdir,"mkdir -p %s",dir);
+//   sprintf(wdir,"mkdir -p %s",dir);
+   sprintf(wdir,"%s",dir);
    if(strlen(us) > 0) {
       strcat(wdir,"-");
       strcat(wdir,us);
@@ -506,13 +617,37 @@ void vrfydir(char *dir, char *dirname, char *per1, char *addr, char *site, char
       strcat(wdir,site);
    }
 
-   system(wdir);
+   my_mkdir(wdir);
 
    sprintf(dirname,"%s",wdir+9);
+   sprintf(images,"%s/images",outdir);
+   mkdir(images,0755);
 
-   sprintf(wdir,"date >%s/%s",dirname,"date");
+   sprintf(wdir,"date >%s/%s",dirname2,"date");
    system(wdir);
 
+   sprintf(per2,"%s/images",SYSCONFDIR);
+   dirp = opendir(per2);
+   while ((direntp = readdir( dirp )) != NULL ){
+      if(strncmp(direntp->d_name,".",1) == 0)
+         continue;
+      sprintf(val10,"%s/%s",per2,direntp->d_name);
+      sprintf(val11,"%s/%s",images,direntp->d_name);
+      img_in = fopen(val10, "rb");
+      img_ou = fopen(val11, "wb");
+      while (c!=EOF) {
+         c = fgetc(img_in);
+         if(c==EOF) break;
+         fputc(c,img_ou);
+      }
+    
+      c=0;
+      fclose(img_in);
+      fclose(img_ou);
+   }
+   (void) rewinddir(dirp);
+   (void) closedir(dirp);
+
    return;
 
 }
@@ -674,7 +809,7 @@ char *subs(char *str, char *from, char *to)
 }
 
 
-void removetmp(char *outdir, int debug)
+void removetmp(char *outdir)
 {
 
    FILE *fp_in;
@@ -758,6 +893,7 @@ void fixnone(char *str)
    return;
 }
 
+#ifdef LEGACY_TESTVALIDUSERCHAR
 int testvaliduserchar(char *user)
 {
 
@@ -772,6 +908,25 @@ int testvaliduserchar(char *user)
    }
    return 0;
 }
+#else
+int testvaliduserchar(char *user)
+{
+
+   char * p_UserInvalidChar = UserInvalidChar ;
+   char * p_user ;
+
+   while( *p_UserInvalidChar ) {
+      p_user = user ;
+      while ( *p_user ) {
+         if( *p_UserInvalidChar == *p_user )
+            return 1;
+         p_user++ ;
+      }
+      p_UserInvalidChar++ ;
+   }
+   return 0;
+}
+#endif
 
 int compar( const void *a, const void *b )
 { if( *(int *)a > *(int *)b ) return 1;
@@ -826,3 +981,55 @@ int getnumlist( char *buf, numlist *list, const int len, const int maxvalue )
    } while( flag );
   return 0;
 }
+
+
+void show_info(FILE *fp_ou)
+{
+
+   if(strcmp(ShowSargInfo,"yes") == 0) {
+      zdate(ftime, DateFormat);
+      sprintf(html,"<center><table><tr><td><br><br></td><td class=\"info\">%s <a href='%s'><font class=\"info\">%s-%s</font></a> %s %s</td></tr></table></center>\n",text[108],URL,PGM,VERSION,text[109],ftime);
+      fputs(html,fp_ou);
+   }
+}
+
+void show_sarg(FILE *fp_ou, char *ind)
+{
+   if(strcmp(ShowSargLogo,"yes") == 0) {
+      fputs("<center><table cellpadding=0 cellspacing=0>\n",fp_ou);
+      sprintf(html,"<tr><th class=\"logo\"><a href=\"http://www.sarg-squid.org\"><img src=\"%s/images/sarg.png\" border=\"0\" align=\"absmiddle\" title=\"SARG, Squid Analysis Report Generator. Logo by Osamu Matsuzaki\"></a>&nbsp;<font class=\"logo\">Squid Analysis Report Generator</font></th></tr>\n",ind,Title);
+      fputs(html,fp_ou);
+      sprintf(html,"<tr><th class=\"title\">&nbsp</th></tr>\n",Title);
+      fputs(html,fp_ou);
+      fputs("<table>\n",fp_ou);
+   }
+}
+
+char url_module(char *url, char *w2)
+{
+   int x, y;
+   char w[255];
+
+   bzero(w, 255);
+   bzero(w2, 255);
+   y=0;
+   for(x=strlen(url)-1; x>=0; x--) {
+      if(url[x] == '/' || y>255) break;
+      w[y]=url[x];
+      y++;
+   }
+
+   y=0;
+   for(x=strlen(w)-1; x>=0; x--) {
+      w2[y]=w[x];
+      y++;
+   }
+
+   return;
+}
+
+void version()
+{
+   printf("SARG Version: %s\n",VERSION);
+   exit(0);
+}
